function [qme,qde,qke,rhse,dum3]=elcd(ielem,coord,top,mat,pos,sol,soln,dum1,dum2);
%
% convection diffusion element element
%
% Parameters:
%
%  qme		: element mass matrix 
%  qde		: element damping matrix 
%  qe       : element stiffness matrix
%  rhse     : element right hand side
%  coord    : coordinates of all nodes
%  top      : topology array
%  ielem    : element number
%  mat      : material properties
%  				c    = mat(imat,1); (diffusion coefficient)
%				fx	 = mat(imat,2);	(factor for convective velocity in x-direction)
%				fy	 = mat(imat,2);	(factor for convective velocity in y-direction)
%  				axi  = mat(imat,4);	(0: plane strain, 1: axi-symmetric, 2: plane stress)

qme=[]; qde=[]; dum3=[];

% get the number of nodes on this elemen
[nnodes,nsd,nelem,maxnlnodes,iimat,iitype] = sysinfo(size(coord),size(top));
nlnodes=length(nonzeros(top(ielem,1:maxnlnodes)));

% get the coordinates of the nodes of this elemen
nodcoord=coord(top(ielem,1:nlnodes),:);

% pick up some material parameter
imat=top(ielem,nlnodes+1);
c      = mat(imat,1);
fx     = mat(imat,2);
fy     = mat(imat,3);
axi    = mat(imat,4);

% element topology
etop     = top(ielem,:);

% position of the local degrees of freedom in the global solution array
[vpos,vshp]             = elcd_i(1,[],etop,mat,5);
[n,dn,intworg,intcoord] = elcd_s([],[],etop,mat,vshp(1,:));

% number of dofs for the temperature
nedof = length(nonzeros(vpos(1,:)));

% number of integration points
nint   = length(intworg);

% extract the location of the displacement degrees of freedom
it = nonzeros(vpos(1,:));

% initialize qe and rhs
qke=zeros(nedof,nedof);
qde=qke;
qme=qke;

rhse=zeros(nedof,1);

% perform the element integration
for int=1:nint
   
   % compute x (=r)-coordinate for axi-symmetric case
   x=n(int,:)*nodcoord(:,1);
   y=n(int,:)*nodcoord(:,2);
   if (axi==1),
      intw=2*pi*x*intworg;
   else
      intw=intworg;
   end
   
   % get the convective velocity
   [ax,ay]=elcd_a(x,y,fx,fy);
  
   %* get shape function derivatives with respect to global coordinates
   [dndxy,detj]=getderiv(dn,nodcoord,int);
   
   intwdetj=intw(int)*detj;
   
   % diffusion part
   qke = qke + c*(dndxy(:,1)*dndxy(:,1)' + dndxy(:,2)*dndxy(:,2)')*intwdetj;
   
   % convection part
   qde = qde + (ax*n(int,:)'*dndxy(:,1)' + ay*n(int,:)'*dndxy(:,2)')*intwdetj;
   
   % mass matrix
   qme = qme + n(int,:)'*n(int,:)*intwdetj;
   
end

