function [par1,par2]=elcd_i(ielem,coord,top,mat,ichois);
%
% description:
%
%   This class of elements solves either the incompressible Stokes problem
%   or a (in) compressible elasticity problem
%    
% ietype:
%
% 1 - linear triangle
% 2 - quadratic triangle
% 3 - bilinear quad
% 4 - biquadratic quad
% 
[nnodes,nsd,nelem,maxnlnodes,iimat,iitype]=sysinfo(size(coord),size(top));

imat     = top(ielem,iimat);
ietype   = mat(imat,11);
nlnodes  = length(nonzeros(top(ielem,1:maxnlnodes)));

par1=[]; par2=[];


if (ichois==1),
   
   if ietype==1,
      par1=[1 1 1]; 					% Linear triangular-element
   elseif ietype==2,
      par1=[1 1 1 1 1 1];   		% Quadratic element
   elseif ietype==3, 	
      par1=[1 1 1 1];	    		% Bilinear element
   elseif ietype==4,
      par1=[1 1 1 1 1 1 1 1 1];  % Biquadratic element
   end
   
   npar=length(par1);
   if npar~=nlnodes,
      string_err = ['Number of nodes = ' num2str(nlnodes) ...
            ' for element type ' num2str(ietype) ...
            ' in ielem ' num2str(ielem) ', should be '];
      error([string_err num2str(npar)]);
   end
    
      
elseif (ichois==2),
   
   if (ietype==1),
      par1=2*ones(1,nlnodes);
   elseif ietype==2,
      par1=2*ones(1,nlnodes);
   elseif ietype==3,
      par1=2*ones(1,nlnodes);
   elseif ietype==4,
      par1=2*ones(1,nlnodes);
   end
   
   
elseif (ichois==3),
   
   if (ietype==1),
      par1=[1 2; 2 3; 3 1];
   elseif (ietype==2),
      par1=[1 2; 2 3; 3 4; 4 5; 5 6; 6 1];
   elseif (ietype==3),
      par1=[1 2; 2 3; 3 4; 4 1];
   elseif (ietype==4),
      par1=[1 2; 2 3; 3 4; 4 5; 5 6; 6 7; 7 8; 8 1];
   end
   
elseif (ichois==4),
   
   
   if (ietype==1),
      % linear triangle
      gshp = [23 2 4];
      
   elseif (ietype==2),
      % 6-noded triangle
      gshp(1,:)   = [26 2 7];
      
   elseif (ietype==3),
      % 4-noded quad 
      gshp(1,:)   = [14 1 2];
      
   elseif (ietype==4),
      % 9-noded quad 
      gshp(1,:)   = [19 1 3];
      
   end
   par1=gshp;
   
   
   
elseif (ichois==5),
   
   if (ietype==1),
      % 3-noded triangle with linear pressure
      vpos        = zeros(1,3);
      vpos(1,:)   = 1:3;
      
      vshp      = zeros(1,3);
      vshp(1,:) = [23 2 4];
      
   elseif (ietype==2),
      % 6-noded triangle
      vpos        = zeros(1,nlnodes);
      vpos(1,:)   = 1:nlnodes;
      
      vshp        = zeros(1,3);
      vshp(1,:)   = [26 2 7];
      
   elseif (ietype==3),
      % 4-noded quad
      vpos        = zeros(1,nlnodes);
      vpos(1,:)   = 1:nlnodes;
      
      vshp        = zeros(1,3);
      vshp(1,:)   = [14 1 2];
      
   elseif (ietype==4),
      % 9-noded quad
      vpos        = zeros(1,nlnodes);
      vpos(1,:)   = 1:nlnodes;
      
      vshp        = zeros(1,3);
      vshp(1,:)   = [19 1 3];
      
   end
   par1=vpos; par2=vshp;
   
elseif ichois==6,
   
   if ietype==1,
      
      par1=[1 0; 0 1; 0 0;];
      
   elseif ietype==2,
      
      par1=[1 0; 1/2 1/2; 0 1; 0 1/2; 0 0; 1/2 0];
      
   elseif ietype==3,
      
      par1=[-1 -1; 1 -1; 1 1; -1 1;];
      
   elseif ietype==4,
      
      par1=[-1 -1; 0 -1; 1 -1; 1 0; 1 1; 0 1; -1 1; -1 0; 0 0];
        
   end
   
elseif ichois==7,
   
   if ietype==1 | ietype==2 | ietype==3 | ietype==4 | ietype==5,
      
      nvar=4; nmode=1;
      
      if ietype==1, nint=4; end
      if ietype==2, nint=9; end
      if ietype==3, nint=9; end
      if ietype==4, nint=7; end
      if ietype==5, nint=7; end
      
   end
   par1=[nint nvar nmode];      
      
else
 
   error([' Ichois = ' num2str(ichois) ' not supported ']);

end
   
      


