function [qe,rhse]=elm1d(ielem,coord,top,mat);
%
% One dimensional diffusion problem
% 
% d/dx(c du/dx) + f = 0
%
% Parameters:
%
% Input:
%  ielem    : element number
%  coord    : coordinates of all nodes
%  top      : topology array
%  mat      : material properties
%
% Output:
%  qe       : element stiffness matrix
%  rhse     : element right hand side

% get the number of nodes on this element
[nnodes,nsd,nelem,maxnlnodes,iimat,iitype] = sysinfo(size(coord),size(top));
nlnodes = length(nonzeros(top(ielem,1:maxnlnodes)));

% get the coordinates of the nodes of this elemen
nodcoord=coord(top(ielem,1:nlnodes),:);

% pick up some material parameters
imat=top(ielem,nlnodes+1);
c = mat(imat,1);
f = mat(imat,3);

% element topology
etop=top(ielem,:);

% position of the local degrees of freedom in the global solution array
[vpos,vshp]             = elm1d_i(1,[],etop,mat,5);
[n,dndxi,intw,intcoord] = elm1d_s([],[],etop,mat,vshp(1,:));

nint=length(intw);
ndofu=length(nonzeros(vpos));

% initialize qe and rhse
qe=zeros(ndofu,ndofu);
rhse=zeros(ndofu,1);

for int=1:nint
   
   %* get shape function derivatives with respect to global coordinates
   [dndxy,detj]=getderiv(dndxi,nodcoord,int);
   
   %* compute the 'strain displacement' matrix
   b=dndxy(:,1)';
   
   % contribution to the element coefficient matrix
   qe=qe+b'*c*b*intw(int)*detj;
   
   %* apply source term
   rhse = rhse + n(int,:)'*f*intw(int)*detj;
   
end


