function [sigma]=elm1d_d(ielem,coord,top,mat,pos,sol);
%
% linear elastic element
%
% Parameters:
%
% Input:
%  ielem    : element number
%  coord    : coordinates of all nodes
%  top      : topology array
%  mat      : material properties
%  pos      : pos array, see mpos
%  sol		: solution array
%
% Output:
%  sigma    : stresses at the nodes of each element (stress(ielem,:))

% get the number of nodes on this elemen
[nnodes,nsd,nelem,maxnlnodes,iimat,iitype] = sysinfo(size(coord),size(top));
nlnodes = length(nonzeros(top(ielem,1:maxnlnodes)));

% get the coordinates of the nodes of this elemen
nodcoord=coord(top(ielem,1:nlnodes),:);

% pick up some material parameters

imat=top(ielem,nlnodes+1);
c = mat(imat,1);
f = mat(imat,3);

% element topology
etop=top(ielem,:);

% position of the local degrees of freedom in the global solution array
[vpos,vshp]             = elm1d_i(1,[],etop,mat,5);
[n,dndxi,intw,intcoord] = elm1d_s([],[],etop,mat,vshp(1,:));

nint=length(intw);
ndofu=length(nonzeros(vpos));

% initialize qe and rhs
qe=zeros(ndofu,ndofu);
rhse=zeros(ndofu,1);

% get the nodal solution
unod=sol(pos(ielem,:));

% stresses at the integration points
sigmaint=zeros(2,1);

for int=1:nint

    %* get shape function derivatives with respect to global coordinates
    [dndxy,detj]=getderiv(dndxi,nodcoord,int);

    %* compute the strain displacement matrix
    b=dndxy(:,1)';
        
    % stress (c du/dx) at this integration point
    sigmaint(int) = c*b*unod;
    
end

% sigmaint can be extrapolated to the nodes
sigma = (n\sigmaint)';
