function [par1,par2]=elm1d_i(ielem,coord,top,mat,ichois);
%
% description:
%
%   This class of elements solves either the incompressible Stokes problem
%   or a (in) compressible elasticity problem
%
%   paramters in the mat array
%     mat( 1) = g      : viscosity or Young's modulus
%     mat( 2) = kappa  : compression modulus if 0, incompressibility is assumed
%    
% ietype:
%
% 1 - 2-noded linear element 
% 2 - 3-noded quadratic element

[nnodes,nsd,nelem,maxnlnodes,iimat,iitype]=sysinfo(size(coord),size(top));

imat     = top(ielem,iimat);
ietype   = mat(imat,5);
nlnodes  = length(nonzeros(top(ielem,1:maxnlnodes)));

par1=[]; par2=[];


% definition of number of degrees of freedom for each node
if (ichois==1),
   
   if (ietype==1),
      par1=[1 1]; 					% Linear element
   elseif (ietype==2),
      par1=[1 1 1];					% quadratic element
   end
   
   npar=length(par1);
   if npar~=nlnodes,
      string_err = ['Number of nodes = ' num2str(nlnodes) ...
            ' for element type ' num2str(ietype) ...
            ' in ielem ' num2str(ielem) ', should be '];
      error([string_err num2str(npar)]);
   end
   
   
elseif (ichois==2),
   
   if (ietype==1),
      par1=3*ones(1,nlnodes);
   elseif ietype==2,
      par1=4*ones(1,nlnodes);
   elseif ietype==4,
      par1=4*ones(1,nlnodes);
   end
   
   
elseif (ichois==3),
   % definition of sequence of nodes for plotting purposes
   if (ietype==1),
      par1=[1 2];
   elseif (ietype==2),
      par1=[1 2 3];
   end
   
   
elseif (ichois==4),
   % shape function that defines the geometry
   if (ietype==1),
      % linear 
      gshp = [2 1 2];
      
   elseif (ietype==2),
      % quadratic
      gshp(1,:)   = [3 1 3];
           
   end
   
   par1=gshp;
   
   
   
elseif (ichois==5),
   % defintion of location of dofs (vpos) and their shape functions
   
   if (ietype==1),
      % linear element
      vpos        = zeros(1,2);
      vpos(1,:)   = 1:2;
      
      vshp      = zeros(1,3);
      vshp(1,:) = [2 1 2];
      
   elseif (ietype==2),
      % quadratic element
      vpos        = zeros(1,nlnodes);
      vpos(1,:)   = 1:3;
      
      vshp        = zeros(1,3);
      vshp(1,:)   = [3 1 3]
   end
   
   par1=vpos; par2=vshp;
   
else
   
   error([' Ichois = ' num2str(ichois) ' not supported ']);

end
   
      


