function [qme,qde,qe,rhse]=elm1dcd_supg(ielem,coord,top,mat);
%
% linear elastic element
%
% Parameters:
%
%  qe       : element stiffness matrix
%  rhse     : element right hand side
%  coord    : coordinates of all nodes
%  top      : topology array
%  ielem    : element number
%  mat      : material properties

% get the number of nodes on this element

[nnodes,nsd,nelem,maxnlnodes,iimat,iitype] = sysinfo(size(coord),size(top));
nlnodes = length(nonzeros(top(ielem,1:maxnlnodes)));

% get the coordinates of the nodes of this element

nodcoord=coord(top(ielem,1:nlnodes),:);

% pick up some material parameters

imat=top(ielem,nlnodes+1);

c     = mat(imat,1);   % diffusion coefficient
a     = mat(imat,2);   % convection velocity
f     = mat(imat,3);   % volume force

% element topology
etop=top(ielem,:);

% position of the local degrees of freedom in the global solution array
[vpos,vshp]             = elm1dcd_i(1,[],etop,mat,5);
[n,dndxi,intw,intcoord] = elm1dcd_s([],[],etop,mat,vshp(1,:));

nint=length(intw);
ndofu=length(nonzeros(vpos));

% initialize qe, qme and qde and rhse

qe=zeros(ndofu,ndofu);
qde=qe;
qme=qe;

rhse=zeros(ndofu,1);

h=max(nodcoord)-min(nodcoord);
beta=abs(a)*h/(2*c);
alpha=coth(beta)-1/beta;

for int=1:nint

    %* get shape function derivatives with respect to global coordinates
    [dndxy,detj]=getderiv(dndxi,nodcoord,int);

    %* compute the strain displacement matrix

    b=dndxy(:,1)';
    
    %* diffusion part
    qe=qe+b'*c*b*intw(int)*detj;
    
    %* convection part
    qde=qde+(n(int,:)'+h*alpha*a/(2*abs(a))*dndxy(:,1))*a*dndxy(:,1)'*intw(int)*detj;
    
    %* mass matrix
    qme=qme+n(int,:)'*n(int,:)*intw(int)*detj;
    
    %* apply volume forces
    rhse=rhse + n(int,:)'*f*intw(int)*detj;
    
end
   
