function [coord,top,topbnd,usercurves,usersurfaces,pot,userpoints]=transmesh(p,e,t,ichois,g);
%
% [coord,top,topbnd,usercurves,usersurfaces,pot,userpoints]=transmesh(p,e,t,ichois);
% [coord,top,topbnd,usercurves,usersurfaces,pot,userpoints]=transmesh(p,e,t,ichois,g);
%
% Input
%  p,e,t  		: mesh output arrays from pdetool
%  ichois 		: 'lt' : linear triangular element
%                'elt': extended linear triangular element (mini-element)
%                'qt' : quadratic triangular element
%                'eqt': extended quadratic triangular element (Crouzeix-Raviart)
%
% Output
%  coord  		: nodal coordinates
%  top    		: topology 
%  topbnd 		: topology of the usercurves
%  usercurves	: nodes on the usercurves
%  usersurfaces: nodes on the subdomains
%  pot         : the inverse topology array
%  userpoints  : nodes that define the basic points of the domain
%

if nargin<5, g=[]; end

if ~strmatch(ichois,strvcat('lt','elt','eqt','qt')),
   error(['Element type must be lt, elt, qt or eqt']);
end

if strmatch(ichois,strvcat('lt','elt'))
	%if ichois==1 | ichois==2, %linear triangles or 'mini-element'
   
   top=[t' t(4,:)'];
   coord=p';
   ncrv=max(e(5,:));
   n=length(e(1,:));
   usercurves=zeros(ncrv,n);
   for icrv=1:ncrv
      ii=find(e(5,:)==icrv);
      nodes=unique(e(1:2,ii)); nnodes=length(nodes);
      usercurves(icrv,1:nnodes)=nodes(:)';
   end
   
   if strmatch(ichois,'elt'),
   %if ichois==2,
      nnodes=length(coord(:,1));
      nelem=length(t(1,:));
      nodes=(1:nelem)'+nnodes;
      top=[top(:,[1 2 3]) nodes top(:,[4 5])];
      x=coord(:,1);
      x=x(top(:,[1 2 3]));
      coord(nodes,1)=mean(x')';
      y=coord(:,2);
      y=y(top(:,[1 2 3]));
      coord(nodes,2)=mean(y')';
   end
   
elseif strmatch(ichois,strvcat('qt','eqt')),
   %elseif ichois==3 | ichois==4, %	quadratic triangular elements
   
   ncrv=max(e(5,:));
   n=length(e(1,:));
   usercurves=zeros(ncrv,n);
   for icrv=1:ncrv
      ii=find(e(5,:)==icrv);
      nodes=unique(e(1:2,ii)); nnodes=length(nodes);
      usercurves(icrv,1:nnodes)=nodes(:)';
   end
   
   nelem=length(t(1,:));
   nnodes=length(p(1,:));
   top_lin=[t' t(4,:)'];
   top    =[t(1:3,:)' zeros(nelem,3) t(4,:)' t(4,:)'];
   pot=toppot(top_lin);
   edge=[1 2; 2 3; 3 1];
   edges=[t(1:2,:)'; t(2:3,:)'; t([3 1],:)'];
   k=nnodes;
   
   enum=sort(e(1:2,:))';
   
   coord=[p';p'];
   
   for ielem=1:nelem,
      ii=find(top(ielem,1:6)==0);
      jj=find(top(ielem,1:6)~=0);
      if ~isempty(ii);
         edgelist=nonzeros(ii);
         n=length(edgelist);
         for l=1:n;
            ied=edgelist(l);
            k=k+1;
            top(ielem,ied)=k;
            iedge=ied-3;
            nods=top(ielem,edge(iedge,:));
            elms=intersect(nonzeros(pot(nods(1),:)),nonzeros(pot(nods(2),:)));
            i=find(elms~=ielem);
            elm_nxt=elms(i);
            
            [c,ed]=intersect(enum,sort(nods),'rows');
            if ~isempty(ed),
               icrv=e(5,ed);
               n=length(nonzeros(usercurves(icrv,:)));
               usercurves(icrv,n+1)=k;
               
               if ~isempty(g),
                  s=mean(e(3:4,ed));
                  bs=icrv;
                  [x,y]=feval(g,bs,s);
                  coord(k,:)=[x y];
               else
                  coord(k,:)=mean(p(:,nods)');
               end
               
            else
               
               coord(k,:)=mean(p(:,nods)');
            end
            
            
            if ~isempty(elm_nxt),
               nodes=top(elm_nxt,1:3);
               [ints,ia,ib]=intersect(nodes,nods);
               ia=sort(ia);
               if nnz(sort(ia)==[1 2])==2,
                  top(elm_nxt,4)=k;
               elseif nnz(sort(ia)==[1 3])==2,
                  top(elm_nxt,6)=k;
               elseif nnz(sort(ia)==[2 3])==2,
                  top(elm_nxt,5)=k;
               end
               

            end
         end
      end
   end
   
   top=top(:,[1 4 2 5 3 6 7 8]);
   coord=coord(1:k,:);
   
   if strmatch(ichois,'eqt'),
   %if ichois==4,
      nnodes=length(coord(:,1));
      nodes=(1:nelem)'+nnodes;
      top=[top(:,[1 2 3 4 5 6]) nodes top(:,[7 8])];
      x=coord(:,1);
      x=x(top(:,[1 3 5 ]));
      coord(nodes,1)=mean(x')';
      y=coord(:,2);
      y=y(top(:,[1 3 5]));
      coord(nodes,2)=mean(y')';
   end
   
   
end


%[x,y,bs_c]=defgeomd_coarse(xyp,curves,subareas);
if ~isempty(g),
   [xyp,curves,subareas]=feval(g,-1);
   [x,y,bs_c]=eval(g);
   
   ncrv=length(curves);
   for icrv=1:ncrv
      bs=nonzeros(bs_c(icrv,:));
      nodes=unique(nonzeros(usercurves(bs,:))); nnodes=length(nodes);
      userc(icrv,1:nnodes)=nodes(:)';
   end
   usercurves=userc;
end

pot=toppot(top);
if strmatch(ichois,strvcat('qt','eqt'));
   elgraph=[1 2; 2 3; 3 4; 4 5; 5 6; 6 1];
else
   elgraph=[1 2; 2 3; 3 1];
end

nodnod=transmesh_nodpot(coord,top,pot,elgraph);

[nnodes,nsd,nelem,maxnlnodes,iimat,iitype] = sysinfo(size([]),size(top));

[usercurves,userpoints,usersurfaces,topbnd]=transmesh_crv(usercurves,coord,top,pot,nodnod,ichois);

%28-09-99 top(:,iimat)=ones(nelem,1);
%28-09-99 top(:,iitype)=ones(nelem,1);
      
      
      

           
        

