%  SCRIPT TO SOLVE THE ONE-DIMENSIONAL DIFFUSION PROBLEM
%
%   d/dx(c du/dx) + f = 0
%
%   Last changed:    21-5-2008   Cees Oomens

disp(' start 1 D diffusion ')
clear, close all

%%%%%%%%%%      DEFINE THE MESH       %%%%%%%%%%

xmin=   0;    	
xmax=   1;    
nelem= 10;  

norder=1; % element order

% generate the mesh
if norder==1,
   dx=(xmax-xmin)/nelem;  %The distance between the nodes
   coord=(xmin:dx:xmax)'; %and the corresponding nodal coordinates.
   
   top=[(1:nelem)' (2:nelem+1)' ones(nelem,2)]; % Element topology
   
elseif norder==2,
   dx=(xmax-xmin)/(2*nelem); %The distance between the nodes
   coord=(xmin:dx:xmax)';    %and the corresponding nodal coordinates.
   
   top=[(1:2:nelem*2)' (2:2:(nelem*2+1))' (3:2:(nelem*2+2))' ones(nelem,2)];
end

disp(' mesh created ')

%%%%%%%%%% DEFINE THE MATERIAL PROPERTIES %%%%%%%%%%

mat.mat(1)=1;	    % c: diffusion coefficient 
mat.mat(3)=1;	    % f: source term
mat.mat(4)=norder;  % norder: element order

mat.types=['elm1d'];% element type

%%%%%%%%%% DEFINE THE BOUNDARY CONDITIONS %%%%%%%%%%

bndcon=[1       1 0
        nelem+1 1 0];

nodfrc=[];

%%%%Solve the problem using the 1D fem program FEM1D %%%%

fem1d
disp(' problem solved ')

%%%%%%%%%%%%%%%% POSTPROCES THE DATA %%%%%%%%%%%%%%%%%%%%%%%

subplot(1,2,1), 
plot(coord,sol,'-'); 
xlabel('x'), ylabel('u');

subplot(1,2,2)
if norder==1,
   plot([coord(1:nelem) coord(2:nelem+1)]',sigma')
elseif norder==2,
   plot([coord(1:2:2*nelem) coord(2:2:2*nelem+1) coord(3:2:2*nelem+2)]',sigma')
end
xlabel('x'), ylabel('\sigma');

%%%%%%%%%%%%%%%%%%%%%%%%%%% END %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
