%%%%%%%%% DEMO OF FEM1DCD   %%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% this code solves the 1D diffusion problem
%
% du/dt + a du/dx = d/dx(c du/dx) + f
%
%    Last change: 21-5-2008 Cees Oomens

disp(' start 1 D convection diffusion ')

clear all           % clears memory
close all           % closes all figures

%%%%%%%%%%  DEFINE THE MESH      %%%%%%%%%%
xmin   =  0;   		% domain = [xmin xmax]
xmax   =  1;   		%
nelem  = 10;	  	% number of elements

norder =  1;        % element order

% coordinates

dx=(xmax-xmin)/nelem;     % The distance between the nodes
coord=(xmin:dx:xmax)';    % The nodal coordinates.

% element topology

top=[(1:nelem)' (2:nelem+1)' ones(nelem,2)]; 

disp(' mesh created ')

%%%%% CONTROLPARAMETERS FOR TIME INTEGRATION %%%%%
istat  =    2;   	% 1: steady state problem,
                    % 2: unsteady problem
dt     = 0.01; 	    % magnitude of time step
ntime  =   10;  	% number of time steps
theta  =  0.5;   	% theta parameter of theta-time 
                    % integration scheme

%%%%%%%%%% DEFINE THE MATERIAL PROPERTIES %%%%%%%%%%
mat.mat(1)=1;		  % c: diffusion coefficient
mat.mat(2)=1;  	      % v: convective velocity
mat.mat(3)=0;		  % f: source term
mat.mat(5)=norder;    % norder: element order

mat.types=['elm1dcd']; % element type


%%%%%%%%%% DEFINE THE BOUNDARY CONDITIONS %%%%%%%%%%

bndcon=[1       1 0
        nelem+1 1 1];

nodfrc=[]  

%%%% SOVE THE PROBLEM USING FEM1DCD %%%
fem1dcd

disp(' problem solved ')

%%%% POST PROCESS THE DATA %%%%

plot(coord,sol);
xlabel('x')
ylabel('u')
title('u as a function of position and time')

%%%%%%%%%%%%%%%%%%%%%%    END   %%%%%%%%%%%%%%%%%%%%%%%%%
