% Script to solve one-dimensional diffusion problems with mlfem_nac
%
% Definition of variables:
%                   nnodes: number of nodes
%                   nsd   : space dimension (1 or 2)
%                   nelem : number of elements
%                   maxnlnodes: maximum number of nodes in an element
%                   q:   the global stiffness matrix 
%                   rhs: the global right-hand-side column
%
%   Last change:     Cees Oomens 14-5-2008 


% Determine some global variables by the function sysinfo.
[nnodes,nsd,nelem,maxnlnodes] = sysinfo(size(coord),size(top));

% Compute the pos and dest array
[pos,dest]=equatnr(coord,top,mat);

% ndof: the total number of degrees of freedom
ndof = max(max(pos));

% define the number of unknows for each node
ldof = length(pos(1,:));

% initialize q and rhs;
% spalloc is a Matlab routine to allocate space for a sparse matrix)
q    = spalloc(ndof,ndof,sum(ldof)^2);
rhs  = zeros(ndof,1);


for ielem=1:nelem
   % compute the element stiffness matrix and right-hand-side array using
   % elm1d 
   [qe,rhse]=elm1d(ielem,coord,top,mat.mat);
   
   % assemble the global stiffness matrix and the right-hand-side array
   ii=pos(ielem,:);
   q(ii,ii) = q(ii,ii) + qe;
   rhs(ii)  = rhs(ii)  + rhse;
end

%  solve the system of equations 
%  solvestat takes care of boundary conditions and partitioning of system of equations
sol=solvestat(q,rhs,bndcon,nodfrc,dest);

% compute the rhs including the reaction forces
rhs=q*sol;

%* compute the stresses
sigma=zeros(nelem,maxnlnodes);
for ielem=1:nelem
    sigma(ielem,:)=elm1d_d(ielem,coord,top,mat.mat,pos,sol);
end

