function [Xout,Yout,Zout]=GPLOTM(A,xyz,lc)

%GPLOTM	Plot a two or three-dimensional "graph theoretic" graph.
%	GPLOT(A,xy) plots the graph specified by A and xy.
%	A graph, G, is a set of nodes numbered from 1 to n,
%	and a set of connections, or edges, between them.
%	In order to plot G, two matrices are needed.
%	The adjacency matrix, A, has a(i,j) nonzero if and
%	only if node i is connected to node j.  The coordinates
%	array, xyz, is an n-by-3 matrix with the position for
%	node i in the i-th row, xyz(i,:) = [x(i) y(i) z(i)].
%	
%	GPLOTM(A,xyz,lc) uses line type and color instead of the 
%	default, 'r-'.   For example, lc = 'g:'.  See PLOT.
%
%       h = GPLOTM(A,xy,lc) returns the handle to the graphplot
%
%	[X,Y,Z] = GPLOTM(A,xyz) returns the NaN-punctuated vectors
%	X, Y and Z without actually generating a plot. These vectors
%	can be used to generate the plot at a later time if desired.
%	
%	See also SPY, TREEPLOT, SUBMESH, UNMESH.

%       GPLOTM is a modification of GPLOT by John Gilbert, 1991.
%	(Copyright (c) 1984-92 by The MathWorks, Inc.)
%
%       Modified by Joost Horsten, Philips Research, Eindhoven
%       The Netherlands
%
%       modified 6-9-1993, 27-1-1995
%
%

if nargin < 3, 
    lc = 'r-';
end;
c = lc(1); l = lc(2:length(lc));

nsd = length(xyz(1,:));

[i,j] = find(A);
[ignore, p] = sort(max(i,j));
i = i(p);
j = j(p);

% Create a long, NaN-seperated list of line segments,
% rather than individual segments.

X = [ xyz(i,1) xyz(j,1) NaN*ones(size(i))]'; X = X(:);
Y = [ xyz(i,2) xyz(j,2) NaN*ones(size(i))]'; Y = Y(:);
if nsd==3
   Z = [ xyz(i,3) xyz(j,3) NaN*ones(size(i))]'; Z = Z(:);
end

if nsd==2

   if nargout==0,
       line(X, Y, 'linestyle',l,'color,'c');
   elseif nargout==1
       h = line(X, Y, 'linestyle',l,'color,'c');
       Xout = h;
   else
       Xout = X;
       Yout = Y;
   end;

else

   if nargout==0,
       line(X, Y, Z, 'linestyle',l,'color,'c');
   elseif nargout==1
       h = line(X, Y, Z, 'linestyle',l,'color,'c');
       Xout = h;
   else
       Xout = X;
       Yout = Y;
       Zout = Z;
   end;

