function h = plarrow(x,y,dx,dy,double,color)

% h = plarrow(x,y,dx,dy,double,color)
%
% draws a set of arrows in a 2D plane 
%
% X,Y   : arrow start (tail) point (may be vectors)
% DX,DY : arrow head positions, relative to tail 
%         (arrows are drawn form [x y] to [x+dx y+dy])
% double: optional choice parameter, defining the number of heads
%         double = 0 : ordinary arrow (default)
%         double = 1 : a double-headed arrow is drawn
% COLOR : optional character, defining arrow color (default:'g')
%
% plot function 
if nargin == 4
   color  = 'g';
   double = 0;
elseif nargin == 5
   color  = 'g';
end

headlengthratio = 0.2;
headwidthratio  = 0.1;

ax = axis;
scalexy = ( ax(2)-ax(1) ) / ( ax(4)-ax(3) );
scalexy=1;

xtop = x+dx; ytop = y+dy;
xh   = x+(1-headlengthratio).*dx;
yh   = y+(1-headlengthratio).*dy;
dxh  = headwidthratio.*dy*scalexy;
dyh  = headwidthratio.*dx;

%dxh=xtop-xh;
%dyh=ytop-yh;

if ~double

   h0 = line([x xtop (xh-dxh) (xh+dxh) xtop]', ...
      [y ytop (yh+dyh) (yh-dyh) ytop]','Color',color);
   
   hold on
   
   h=fill([xtop (xh-dxh) xh+dxh]',[ytop yh+dyh yh-dyh]',color);
   set(h,'edgec',color)
   
   hold off
   
   %h0 = line([x xtop (xh-dyh) (xh+dyh) xtop]',...
   %          [y ytop (yh+dxh) (yh-dxh) ytop]','color',color);

else

   xh2 = x+(1-2*headlengthratio).*dx;
   yh2 = y+(1-2*headlengthratio).*dy;
   xh3 = x+(1-3*headlengthratio).*dx;
   yh3 = y+(1-3*headlengthratio).*dy;
   h0  = line([x xh (xh2-dxh) (xh2+dxh) xh]', ...
             [y yh (yh2-dyh) (yh2+dyh) yh]', 'Color',color); 
   h1  = line([xh2 (xh3-dxh) (xh3+dxh) xh2]', ...
              [yh2 (yh3-dyh) (yh3+dyh) yh2]', 'Color',color); 
   h0 = [ h0 ; h1 ];
   
end

if nargout>0
   h = h0;
end


