function [] = plbndc(coord,top,mat,bndcon,nodfrc,tiecon)

%
% plbndc(coord,top,mat,bndcon,nodfrc,tiecon)
%
% plots 2d mesh, essential boundary conditions, nodal forces, user
% points and user curves
%
% input:
%   coord        : nodal point coordinates
%   top          : element topology
%   mat          : (optional) material properties
%   bndcon  ([]) : (optional) definition of essential boundary conditions
%   nodfrc  ([]) : (optional) definition of nodal forces
%   tiecon  ([]) : (optional) definition of nodal ties
% 
% plot function

if nargin<3
   mat=[];
end
if nargin<4
   bndcon = [];
end
if nargin<5
   nodfrc = [];
end
if nargin<6
   tiecon = [];
end

nsd = length(coord(1,:));
%if nsd==3
%   plmesh3(coord,top,bndcon,nodfrc)
%   return
%end

double  = 1; single = ~double;

%** boundary conditions
if ~isempty(bndcon),

   bndcoord = coord(bndcon(:,1),:);
   nbndcon = length(bndcon(:,1));
   x = bndcoord(:,1); y = bndcoord(:,2);
   line(x,y,'linestyle','none','marker','o','color','g')

   bndvalue = bndcon(:,3);
   maxbndvalue = max(abs(bndvalue));
   if maxbndvalue == 0 ;
      bndvalue = ones(size(bndvalue));
      maxbndvalue = 1e+10;
   end
   if maxbndvalue < 10e-6;
      bndvalue = ones(size(bndvalue));
      maxbndvalue = 1;
   end

   
   ax = axis;
   maxarrowl = 0.1*min([ax(2)-ax(1) ax(4)-ax(3)]);
   dx = zeros(nbndcon,1); dy = dx;
   %ix = find(bndcon(:,2)==1); dx(ix) = arrowl*ones(size(ix));  
   ix = find(bndcon(:,2)==1); dx(ix) = maxarrowl*bndvalue(ix)/maxbndvalue;  
   iy = find(bndcon(:,2)==2); dy(iy) = maxarrowl*bndvalue(iy)/maxbndvalue;  
   plarrow(x,y,dx,dy,single,'g');
   dx = zeros(nbndcon,1); dy = dx;
   ix = find(bndcon(:,2)==4); dx(ix) = maxarrowl*bndvalue(ix)/maxbndvalue;  
   iy = find(bndcon(:,2)==5); dy(iy) = maxarrowl*bndvalue(iy)/maxbndvalue;  
   plarrow(x,y,dx,dy,double,'g');
   iz = find(bndcon(:,2)==3); 
   if ~isempty(iz)
      line(x(iz),y(iz),'linestyle','non','marker','v','color','g')
   end

end;

%** nodal forces
if ~isempty(nodfrc),

   bndcoord = coord(nodfrc(:,1),:);
   nnodfrc = length(nodfrc(:,1));
   x = bndcoord(:,1); y = bndcoord(:,2);
   line(x,y,'linestyle','none','marker','x','color','y')

   frcvalue = nodfrc(:,3);
   maxfrcvalue = max(abs(frcvalue));
   if maxfrcvalue < 10e-6;
      frcvalue = ones(size(frcvalue));
      maxfrcvalue = 1;
   end
   ax = axis;
   arrowl = 0.1*min([ax(2)-ax(1) ax(4)-ax(3)]);
   dx = zeros(nnodfrc,1); dy = dx;
   ix = find(nodfrc(:,2)==1); dx(ix) = arrowl*frcvalue(ix)/maxfrcvalue;  
   iy = find(nodfrc(:,2)==2); dy(iy) = arrowl*frcvalue(iy)/maxfrcvalue;  
   plarrow(x,y,dx,dy,single,'y');
   dx = zeros(nnodfrc,1); dy = dx;
   ix = find(nodfrc(:,2)==4); dx(ix) = arrowl*frcvalue(ix)/maxfrcvalue;  
   iy = find(nodfrc(:,2)==5); dy(iy) = arrowl*frcvalue(iy)/maxfrcvalue;  
   plarrow(x,y,dx,dy,double,'y');
   iz = find(nodfrc(:,2)==3); 
   if ~isempty(iz)
      line(x(iz),y(iz),'linestyle','none','marker','v','color','y')
   end
end;

%** nodal ties
if ~isempty(tiecon),

   bndcoord = coord(tiecon(:,1),:);
   ntiecon = length(tiecon(:,1));
   x = bndcoord(:,1); y = bndcoord(:,2);
   line(x,y,'linestyle','o','color','y')
   line(x,y,'linestyle','-','color','y')

end


