function [] = pldisp(sol,coord,top,dest,mat,scale,original,idim)

% plots original and original mesh 
% 
% h = pldisp(sol,coord,top,dest)
% h = pldisp(sol,coord,top,dest,mat,scale,original,idim)
%
% input:
%   sol          : displacements, may be either in solution type form or as
%                  nodal displacements
%   coord        : nodal coordinates
%   top          : element topology
%   dest         : destination array 
%   mat          : material parameters (optional)
%   scale        : scale factor (optional)
%   original     : choice parameter, indicating whether the original mesh 
%                  must be drawn fully (2), boundary only (1) or not (0)
%                  if (original==-1), only deformed boundary is shown
%                  (optional)
%   idim         : plot dimension choice parametes 
%                  idim=2: 2 d plot
%                  idim=3: 3 d plot
%                  (optional)


[nnodes,nsd] = size(coord);

%** check input / set defaults
if nargin<5
   mat=[];
end
if nargin<6
   scale=1;
end
if nargin<7
   original = 1;
end
if nargin<8
   idim = nsd;
end

%** set parameters
color    = 'r';
colororg = 'y';

nldof        = length(dest(1,:));
if nsd>3  
   coord = coord(:,1:3); %* length of coord might be >nsd for plate elements
   nsd=3;
end
if idim>nsd
   coord = [coord zeros(nnodes,idim-nsd) ];
end

%** if required, extract nodal displacements from solution vector
[m,n] = size(sol);
if n==1;
   %** sol is solution type vector, extract nodal displacements
   noddisp    = sol2nod(sol,dest);
elseif m==nnodes & n>=nsd
   %** sol is already in nodal form
   noddisp = sol;
else
   error('illegal size of array sol')
end

%** use only components 1:idim (required for e.g. plate elements)
if idim>size(noddisp,2)
   noddisp = [noddisp zeros(nnodes,idim-size(noddisp,2)) ];
else
   noddisp    = noddisp(:,1:idim);
end

%** compute displaced coordinates
coorddisp = coord + scale*noddisp;

%** plot
if idim==2

   a = top2grph(coord,top,mat);
   if original~=-1, 
       gplot(a,coorddisp,color); axis('off'); axis('image');
   end
   if original==1
      [xg,yg] = gplot(a-a',coord);
      line(xg,yg,'linestyle',':','color',colororg);
   elseif original==2
      [xg,yg] = gplot(a,coord);
      line(xg,yg,'linestyle',':','color',colororg);
   elseif original==-1
      [xg,yg] = gplot(a-a',coorddisp);
      line(xg,yg,'linestyle',':','color',colororg);
   end
 
else

   a = top2grph(coord,top,mat);
   if original~=-1, 
      gplot3(a,coorddisp,color); axis('off'); %axis('image');
   end
   if original==1
      [xg,yg,zg] = gplot3(a-a',coord);
      line(xg,yg,zg,'linestyle',':','color',colororg);
   elseif original==2
      [xg,yg,zg] = gplot3(a,coord);
      line(xg,yg,zg,'linestyle',':','color',colororg);
   elseif original==-1
      [xg,yg,zg] = gplot3(a-a',coorddisp);
      line(xg,yg,zg,'linestyle',':','color',colororg);   end

end

axis('image')


