function h=plelem(coord,top,mat,color,style)

% plots elements in an existing mesh
%
% h = plelem(coord,top,mat)
% h = plelem(coord,top,mat,color,style)
%
% input:
%   coord        : nodal coordinates
%   top          : element topology
%   mat          : material parameters (optional)
%   color        : color of the nodes i.e. 'y' (optional)
%   style        : style of the nodes i.e. 'o' (optional)

if nargin<3
   mat=[];
end
if nargin<4
   color = 'g';
end
if nargin<5
   style = '-';
end

[nnodes,nsd,nelem,maxnlnodes] = sysinfo(size(coord),size(top));

if style~='f'

   %** line plot
   if nsd==2
      graphtop = top2grph(coord,top,mat);
      [xg,yg]  = gplot(graphtop,coord);
      h=line(xg,yg,'linestyle',style,'color',color);
   else
      error('3D not yet implemented')
%      graphtop = top2grph3(coord,top,mat);
%      [xg,yg,zg]  = gplot3(graphtop,coord);
%      line(xg,yg,zg,'linestyle',style,'color',color);
   end

else

   %** filled plot
   x = zeros(maxnlnodes,nelem);
   y = zeros(maxnlnodes,nelem);
   z = zeros(maxnlnodes,nelem);
   for iel=1:nelem
       connect = top(iel,1:maxnlnodes);
       elgraph = eleminfo(iel,coord,top,mat,3);
       if isempty(elgraph)
          nodes   = nonzero(connect);
       else
          nodes   = connect(elgraph(:,1));
       end
       nlnodes = length(nodes);
       %* fill dummy values for all possible local nodes
       x(:,iel) = ones(maxnlnodes,1) * coord(nodes(1),1) ;
       y(:,iel) = ones(maxnlnodes,1) * coord(nodes(1),2) ;

       %* fill real values for actual local nodes
       x(1:nlnodes,iel) = coord(nodes,1);
       y(1:nlnodes,iel) = coord(nodes,2);
       if nsd==3
          z(:,iel) = ones(maxnlnodes,1) * coord(nodes(1),3);
          z(1:nlnodes,iel) = coord(nodes,3);
       end
   end 
   if nsd==3
      patch(x,y,z,color); grid;
   else
      patch(x,y,color); axis('off'); axis('image');
   end
end  
 
