function [h] = plelmdat(elmdat,coord,top,mat,ivar,itime,idim,option);

% h=plelmdat(elmdat,coord,top,mat);
% h=plelmdat(elmdat,coord,top,mat,ivar);
% h=plelmdat(elmdat,coord,top,mat,ivar,itime);
% h=plelmdat(elmdat,coord,top,mat,ivar,itime,idim);
% h=plelmdat(elmdat,coord,top,mat,ivar,itime,idim,option);
%
% plots element data on mesh defined by coord,top and mat
%
% input:
%  elmdat     : element nodal data in multidimensional array
%               mdgetmat(elmdat,ielem,ilnode,ivar,itime) =
%               data of variable ivar on local node ilnode of element ielem,
%               on time step itime 
%  coord      : nodal coordinates
%  top        : mesh topology 
%  mat        : materla/element parameter array
%  ivar  (1)  : optional index of dof (default=1)
%  itime (1)  : optional index of time step (default=1)
%  idim  (nsd): optional plot dimension choice parametes 
%               idim=2: 2 d plot
%               idim=3: 3 d plot
%               default idim = nsd (number of spatial dimensions)
%  option     : option(1)=cmin
%             : option(2)=cmax
%
% output:
%  h          : handle of fill(3) (e.g. to set edgecolor set(h,'edgecolor','none')
%

%** get size parameters
[nnodes,nsd,nelem,maxnlnodes,iimat,iitype] = sysinfo(size(coord),size(top));

%** check input / set defaults
if nargin<4,
   error('illegal number of input arguments, must be at least 5');
end
if nargin<5
   ivar = 1;
end
if nargin<6
   itime=1;
end
if nargin<7
   idim  = nsd;
end
if nargin<8,
   option=[];
end

if nargin<4
   error('Too few input arguments, must be at least 4');
end

if isempty(ivar) , ivar  = 1;   end
if isempty(itime), itime = 1;   end
if isempty(idim) , idim  = nsd; end


%** set up data
coord = [coord zeros(nnodes,3-nsd) ];

x = zeros(maxnlnodes,nelem);
y = zeros(maxnlnodes,nelem);
z = zeros(maxnlnodes,nelem);
c = zeros(maxnlnodes,nelem);

maxlnodes=0;
 
for ielem = 1:nelem

    connect = top(ielem,1:maxnlnodes);
    elgraph = eleminfo(ielem,coord,top,mat,3);
    if isempty(elgraph)
       lnodes  = find(connect);
    else
       lnodes  = elgraph(:,1);
    end
    if (length(lnodes)>maxlnodes), maxlnodes=length(lnodes); end
    nodes   = connect(lnodes);
    nlnodes = length(lnodes);

    %* fill dummy values for all possible local nodes
    x(:,ielem) = ones(maxnlnodes,1) * coord(nodes(1),1) ;
    y(:,ielem) = ones(maxnlnodes,1) * coord(nodes(1),2) ;

    %* fill real values for actual local nodes
    x(1:nlnodes,ielem) = coord(nodes,1);
    y(1:nlnodes,ielem) = coord(nodes,2);
    if nsd==3
       z(:,ielem) = ones(maxnlnodes,1) * coord(nodes(1),3);
       z(1:nlnodes,ielem) = coord(nodes,3);
    end
    
    %** fill element data
    %if ~ismd(elmdat),
    %   c(:,ielem)         = ones(maxnlnodes,1) * elmdat(ielem,lnodes(1))';
    %   c(1:nlnodes,ielem) = (elmdat(ielem,lnodes))';
    %else
    %   c(:,ielem)         = ones(maxnlnodes,1) * ...
    %      mdgetmat(elmdat,ielem,lnodes(1),ivar,itime);
    %   c(1:nlnodes,ielem) = mdgetmat(elmdat,ielem,lnodes,ivar,itime);
    %end
    c(:,ielem) = ones(maxnlnodes,1)*elmdat(ielem,lnodes(1),ivar,itime);
    c(1:nlnodes,ielem) = elmdat(ielem,lnodes,ivar,itime)';
    
    if ~isempty(option),
       cmin=option(1);
       cmax=option(2);
       i=find(c(:,ielem)>cmax);
       c(i,ielem)=cmax;
       i=find(c(:,ielem)<cmin);
       c(i,ielem)=cmin;
    end
    
 end;
 
%x=x(1:maxlnodes,:);
%y=y(1:maxlnodes,:);
%z=z(1:maxlnodes,:);
%c=c(1:maxlnodes,:);

if (idim==2),
   h0=fill(x,y,c); 
   axis('off'); axis('image');
   set(h0,'edgecolor','white'); colormap('jet');
elseif nsd==3
   h0=fill3(x,y,z,c); grid; 
   axis('off'); axis('image');
   set(h0,'edgecolor','white'); colormap('jet');
elseif nsd==2,
   h0=fill3(x,y,c,c); grid,% set(gca,'aspectratio',[1 1]);
   axis('on');% axis('image');
   set(h0,'edgecolor','white'); colormap('jet');
end


if nargout>0
   h = h0;
end

colorbar

return
