function [] = plmesh(coord,top,mat,bndcon,nodfrc)

% plots mesh, essential boundary conditions, nodal forces
%
% h = plmesh(coord,top,mat)
% h = plmesh(coord,top,mat,bndcon,nodfrc)
%
% input:
%   coord        : nodal coordinates
%   top          : element topology
%   mat          : material properties
%   bndcon       : definition of essential boundary conditions (optional) 
%   nodfrc       : definition of nodal forces (optional) 

if nargin<3,
   mat=[];
end
if nargin<4
   bndcon = [];
end
if nargin<5
   nodfrc = [];
end
[nnodes,nsd,nelem,maxnlnodes,iimat,iitype] = sysinfo(size(coord),size(top));
double  = 1; single = ~double;
factor  = 0.1;

if nsd<3
%*** 2D mesh

   %** elements
   graphtop = top2grph(coord,top,mat);
   gplot(graphtop,coord,'r-'); axis('off'); axis('image')

   %** boundary conditions
   if ~isempty(bndcon),

      bndcoord = coord(bndcon(:,1),:);
      nbndcon = length(bndcon(:,1));
      x = bndcoord(:,1); y = bndcoord(:,2);
      line(x,y,'Linestyle','none','marker','o','Color','g')

      bndvalue = bndcon(:,3);
      maxbndvalue = max(abs(bndvalue));
      if maxbndvalue < 10e-6;
         bndvalue = ones(size(bndvalue));
         maxbndvalue = 1;
      end
      ax = axis;
      maxarrowl = 0.1*min([ax(2)-ax(1) ax(4)-ax(3)]);
      dx = zeros(nbndcon,1); dy = dx;
      %ix = find(bndcon(:,2)==1); dx(ix) = arrowl*ones(size(ix));  
      ix = find(bndcon(:,2)==1); dx(ix) = maxarrowl*bndvalue(ix)/maxbndvalue;  
      iy = find(bndcon(:,2)==2); dy(iy) = maxarrowl*bndvalue(iy)/maxbndvalue;  
      plarrow(x,y,dx,dy,single,'g');
      dx = zeros(nbndcon,1); dy = dx;
      ix = find(bndcon(:,2)==4); dx(ix) = maxarrowl*bndvalue(ix)/maxbndvalue;  
      iy = find(bndcon(:,2)==5); dy(iy) = maxarrowl*bndvalue(iy)/maxbndvalue;  
      plarrow(x,y,dx,dy,double,'g');
      iz = find(bndcon(:,2)==3); 
      if ~isempty(iz)
         line(x(iz),y(iz),'Linestyle','none','marker','*','Color','g')
      end

   end; % 2D boundary conditions

   %** nodal forces
   if ~isempty(nodfrc),

      bndcoord = coord(nodfrc(:,1),:);
      nnodfrc = length(nodfrc(:,1));
      x = bndcoord(:,1); y = bndcoord(:,2);
      line(x,y,'Linestyle','none','marker','x','Color','y')

      frcvalue = nodfrc(:,3);
      maxfrcvalue = max(abs(frcvalue));
      if maxfrcvalue < 10e-6;
         frcvalue = ones(size(frcvalue));
         maxfrcvalue = 1;
      end
      ax = axis;
      arrowl = 0.1*min([ax(2)-ax(1) ax(4)-ax(3)]);
      dx = zeros(nnodfrc,1); dy = dx;
      ix = find(nodfrc(:,2)==1); dx(ix) = arrowl*frcvalue(ix)/maxfrcvalue;  
      iy = find(nodfrc(:,2)==2); dy(iy) = arrowl*frcvalue(iy)/maxfrcvalue;  
      plarrow(x,y,dx,dy,single,'y');
      dx = zeros(nnodfrc,1); dy = dx;
      ix = find(nodfrc(:,2)==4); dx(ix) = arrowl*frcvalue(ix)/maxfrcvalue;  
      iy = find(nodfrc(:,2)==5); dy(iy) = arrowl*frcvalue(iy)/maxfrcvalue;  
      plarrow(x,y,dx,dy,double,'y');
      iz = find(nodfrc(:,2)==3); 
      if ~isempty(iz)
         line(x(iz),y(iz),'Linestyle','none','marker','*','Color','y')
      end
   end; % 2D nodal forces

else
%**** 3D mesh

   %** elements
   graphtop = top2grph(coord,top,mat);
   gplot3(graphtop,coord,'r-'); axis('off'); axis('image')

   %** 3D boundary conditions
   if ~isempty(bndcon),

      nbndcon = length(bndcon(:,1));
      bndcoord = coord(bndcon(:,1),:);
      xbnd = bndcoord(:,1); ybnd = bndcoord(:,2);
      if (length(coord(1,:)) > 2)
         zbnd = bndcoord(:,3);
      else
         zbnd = zeros(size(xbnd));
      end
      line(xbnd,ybnd,zbnd,'Linestyle','none','marker','o','Color','g')

      ax = axis; axis(ax);
      arrowlx = factor*(ax(2)-ax(1));
      arrowly = factor*(ax(4)-ax(3));
      arrowlz = factor*(ax(6)-ax(5));
      dx = zeros(nbndcon,1); dy = dx; dz = dx;
      ix = find(bndcon(:,2)==1); dx(ix) = arrowlx*ones(size(ix));
      iy = find(bndcon(:,2)==2); dy(iy) = arrowly*ones(size(iy));
      iz = find(bndcon(:,2)==3); dz(iz) = arrowlz*ones(size(iz));
      plarrow3(xbnd,ybnd,zbnd,dx,dy,dz,single,'g');
      dx = zeros(nbndcon,1); dy = dx; dz=dx;
      ix = find(bndcon(:,2)==4); dx(ix) = arrowlx*ones(size(ix));
      iy = find(bndcon(:,2)==5); dy(iy) = arrowly*ones(size(iy));
      iz = find(bndcon(:,2)==6); dz(iz) = arrowlz*ones(size(iz));
      double = 1;
      plarrow3(xbnd,ybnd,zbnd,dx,dy,dz,double,'g');
   end; % 3D nodal forces

   if ~isempty(nodfrc),

      nnodfrc = length(nodfrc(:,1));
      frccoord = coord(nodfrc(:,1),:);
      xfrc = frccoord(:,1); yfrc = frccoord(:,2);
      if (length(coord(1,:)) > 2)
         zfrc = frccoord(:,3);
      else
         zfrc = zeros(size(xfrc));
      end
      line(xfrc,yfrc,zfrc,'Linestyle','none','marker','x','Color','y')

      ax = axis; axis(ax);
      arrowlx = factor*(ax(2)-ax(1));
      arrowly = factor*(ax(4)-ax(3));
      arrowlz = factor*(ax(6)-ax(5));
      dx = zeros(nnodfrc,1); dy = dx; dz = dx;
      ix = find(nodfrc(:,2)==1); dx(ix) = arrowlx*ones(size(ix));
      iy = find(nodfrc(:,2)==2); dy(iy) = arrowly*ones(size(iy));
      iz = find(nodfrc(:,2)==3); dz(iz) = arrowlz*ones(size(iz));
      plarrow3(xfrc,yfrc,zfrc,dx,dy,dz,single,'y');
      dx = zeros(nnodfrc,1); dy = dx; dz=dx;
      ix = find(nodfrc(:,2)==4); dx(ix) = arrowlx*ones(size(ix));
      iy = find(nodfrc(:,2)==5); dy(iy) = arrowly*ones(size(iy));
      iz = find(nodfrc(:,2)==6); dz(iz) = arrowlz*ones(size(iz));
      plarrow3(xfrc,yfrc,zfrc,dx,dy,dz,double,'y');
   end;

end;

