function [h] = plnoddat(noddat,coord,top,mat,ivar,itime,idim);

% h=plnoddat(noddat,coord,top,mat);
% h=plnoddat(noddat,coord,top,mat,ivar,itime,idim);
%
% plots nodal data on mesh defined by coord,top and mat
%
% Input:
%
%  NODDAT : nodal data, may be both in multidimimensional and oridinary form
%           if multidimensional:
%           MDGETMAT(NODDAT,INODE,IVAR,ITIME) = 
%           variable IVAR on node INODE on time ITIME
%           if ordinary:         
%           SCALDAT(INODE,IVAR) = variable IVAR on node INODE  
%  COORD  : nodal coordinates
%  TOP    : mesh topology 
%  MAT    : material/element parameter array
%  IVAR   : optional index of variable (default=1)
%  ITIME  : optional index of time step (default=1)
%  IDIM   : optional plot dimension choice parametes 
%           idim=2: 2 D plot
%           idim=3: 3 D plot
%           default IDIM = NSD (number of spatial dimensions)
%
% Output:
%  H      : handle of fill(3) (e.g. to set edgecolor set(h,'edgecolor','none')
%
% If you want to use a certain component ICOMP of SOL for the colour plot,
% plnoddat can be called according to
%
% plnoddat(sol(dest(:,icomp)),coord,top,mat);
 
% plot function

if nargin<4,
   error('Illegal number of input arguments, must be at least 5');
end
if nargin<5
   ivar  = 1;
end
if nargin<6
   itime  = 1;
end
if nargin<7
   idim  = 2;
end
if (idim~=3 & idim~=2), 
   idim=2;
end

[nnodes,nsd,nelem,maxnlnodes,iimat,iitype] = sysinfo(size(coord),size(top));


sz=size(noddat);
if length(sz)<2, sz(2)=1; end
if length(sz)<3, sz(3)=1; end
if sz(1)~=nnodes | sz(2)<ivar | sz(3)<itime,
   error(['Incorrect size if noddat, or incorrect ivar or itime']);
end

coord = [coord zeros(nnodes,3-nsd) ];

x = zeros(maxnlnodes,nelem);
y = zeros(maxnlnodes,nelem);
z = zeros(maxnlnodes,nelem);
c = zeros(maxnlnodes,nelem);
 
for ielem = 1:nelem

    connect = top(ielem,1:maxnlnodes);
    elgraph = eleminfo(ielem,coord,top,mat,3);
    if isempty(elgraph)
       nodes   = nonzeros(connect);
    else
       nodes   = connect(elgraph(:,1));     
    end
    nlnodes = length(nodes);

    %* fill dummy values for all possible local nodes
    x(:,ielem) = ones(maxnlnodes,1) * coord(nodes(1),1) ;
    y(:,ielem) = ones(maxnlnodes,1) * coord(nodes(1),2) ;

    %* fill real values for actual local nodes
    x(1:nlnodes,ielem) = coord(nodes,1);
    y(1:nlnodes,ielem) = coord(nodes,2);
    if nsd==3
       z(:,ielem) = ones(maxnlnodes,1) * coord(nodes(1),3);
       z(1:nlnodes,ielem) = coord(nodes,3);
    end

    %* fill color with nodal data
    %if mdcheck
    %   dat = mdgetmat(noddat,nodes,ivar,itime);
    %else
    %   dat = noddat(nodes,ivar);
    %end
    dat = squeeze(noddat(nodes,ivar,itime));
             
    c(:,ielem) = ones(maxnlnodes,1) * dat(1) ;
    c(1:nlnodes,ielem) = dat;

end;

if idim==2,
   h0=fill(x,y,c); 
   axis('off'); axis('image');
   set(h0,'edgecolor','white'); colormap('jet');
elseif nsd==3
   h0=fill3(x,y,z,c); grid; 
   axis('off'); axis('image');
   set(h0,'edgecolor','white'); colormap('jet');
elseif idim==3,
   h0=fill3(x,y,c,c); grid,% set(gca,'aspectratio',[1 1]);
   axis('on');% axis('image');
   set(h0,'edgecolor','white'); colormap('jet');
end




if nargout>0
   h = h0;
end

colorbar



