function [hvec,hmesh]=plnodvec(vecdat,scaldat,coord,top,mat,scale,ivar,itime,idim)

% [hvec,hmesh]=plnodvec(vecdat,scaldat,coord,top);
% [hvec,hmesh]=plnodvec(vecdat,scaldat,coord,top,mat);
% [hvec,hmesh]=plnodvec(vecdat,scaldat,coord,top,mat,scale);
% [hvec,hmesh]=plnodvec(vecdat,scaldat,coord,top,mat,scale,ivar);
% [hvec,hmesh]=plnodvec(vecdat,scaldat,coord,top,mat,scale,ivar,itime);
% [hvec,hmesh]=plnodvec(vecdat,scaldat,coord,top,mat,scale,ivar,itime,idim);
%
% creates a combined vector & colour plot from nodal data
%
% VECDAT   : vector nodal data ,may be in multidimensional form (filled
%            with e.g. MDPUTMAT) or oridinary matrix form.
%            if multidimensional:
%            MDGETMAT(VECDAT,INODE,ICOMP,IVAR,ITIME) =             
%            vectorcomponent ICOMP of variable IVAR on node INODE on time ITIME 
%            if ordinary form:
%            VECDAT(INODE,ICOMP) = vectorcomponent ICOMP on node INODE 
%             
% SCALDAT  : scalar nodal data, may be both in multidim. and oridinary form
%            if multidimensional:
%            MDGETMAT(SCALDAT,INODE,IVAR,ITIME) = 
%            variable IVAR on node INODE on time ITIME 
%            if ordinary form:
%            SCALDAT(INODE,IVAR) = variable IVAR on node INODE 
%            if SCALDAT if empty, only the boundary of the mesh will be plotted
%
% COORD    : nodal coordinates
% TOP      : mesh topology
% MAT      : material/element parameter array
% SCALE    : optional scale factor (default = 1)
% IVAR     : optional variable index (default=1)
% ITIME    : optional time step index (default=1)
% IDIM     : optional plot dimension choice parametes 
%            idim=2: 2 D plot
%            idim=3: 3 D plot
%            default IDIM = NSD (number of spatial dimensions)

[nnodes,nsd,nelem,maxnlnodes,iimat,iitype] = sysinfo(size(coord),size(top));

if nargin<5
   mat=[];
end
if nargin<6
   scale = 1;
end
if nargin<7
   ivar = 1;
end
if nargin<8
   itime = 1;
end
if nargin<9
   idim = nsd;
end

%** get parameters & set defaults

% Joost: this routine stinks!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 if ~isempty(scaldat)
    mdcheck1 = ismd(scaldat,length(scaldat));
    if ~mdcheck1   
       [n1,m1] = size(scaldat);
       nvar    = m1;
       if (n1~=nnodes) | (nvar<ivar)
          error('Illegal size of array scaldat')
       end
       scaldat = scaldat(:,ivar);
       nsol    = 1;
    else
       l    = mdsize(scaldat);
       nsol = l(3); 
    end
 end
 mdcheck2 = ismd(vecdat,length(vecdat));
if ~mdcheck2   
   [n2,m2] = size(vecdat);
   if (n2~=nnodes) | (m2~=nsd*nvar)
       error('Illegal size of array vecdat')
   end
   vecdat = vecdat(:,((ivar-1)*nsd+1):(ivar*nsd));
end
ndir = nsd;                   

%** create color plot
if isempty(scaldat),
   plbound(coord,top,mat);
else
   hmesh0=plnoddat(scaldat,coord,top,mat,ivar,itime,idim);
   set(hmesh0,'edgecolor','none');
end

%** select data for vector plot
ii = unique(nonzeros(top(:,1:maxnlnodes))); % plot all nodes used by elements
if mdcheck2
   vec = mdgetmat(vecdat,ii,1:nsd,ivar,itime);
else
   vec = vecdat(ii,:);
end

%** scale vecdat
lmesh = max(max(coord) - min(coord)); 
lvec  = max(max(abs(vec)));
s     = scale * 0.1 * lmesh/lvec;

%** set up plot data   
x  = coord(ii,1);
dx = s*vec(:,1);
y  = coord(ii,2);
dy = s*vec(:,2);
if nsd==3
   z  = coord(ii,3);
   dz = s*vec(:,3);
end 

%** plot vectors
if nsd==2 
   hvec0=plarrow(x,y,dx,dy,0,'w');
else
   hvec0=plarrow3(x,y,z,dx,dy,dz,0,'w');
end

if nargout==1,
   hvec  = hvec0;
elseif nargout==2
   hmesh = hmesh0;
   hvec  = hvec0;
end

%axis('image')






