function h = plqarrow(x,y,dx,dy,double,color)

% h = plqarrow(x,y,dx,dy,double,color)
%
% draws a set of quasi arrows (arrows without arrow head) in a 2D plane 
%
% X,Y   : arrow start (tail) point (may be vectors)
% DX,DY : arrow head positions, relative to tail 
%         (arrows are drawn form [x y] to [x+dx y+dy] if double=0 or
%          from [x-dx y-dy] to x+dx y+dy] if double = 1)
% double: optional choice parameter, defining the number of heads
%         double = 0 : single quasi arrow (default)
%         double = 1 : double arrow 
% COLOR : optional character, defining arrow color (default:'g')
 
if nargin == 4
   color  = 'g';
   double = 0;
elseif nargin == 5
   color  = 'g';
end

[nx,ny] = size(x);
x  = reshape(x,nx*ny,1);
y  = reshape(y,nx*ny,1);
dx = reshape(dx,nx*ny,1);
dy = reshape(dy,nx*ny,1);

if ~double  
   h0 = line([x x+dx]', [y y+dy]');
else  
   h0 = line([x-dx x+dx]', [y-dy y+dy]');
end

set(h0,'color',color);

if nargout>0
   h = h0;
end


