function h = plqarrw3(x,y,z,dx,dy,dz,double,color)

% h = plqarrw3(x,y,z,dx,dy,dz,double,color)
%
% draws a set of quasi arrows (arrows without arrow head) in 3D 
%
% X,Y,Z    : arrow start (tail) point (may be vectors)
% DX,DY,DZ : arrow head positions, relative to tail 
%            (arrows are drawn form [x y] to [x+dx y+dy] if double=0 or
%            from [x-dx y-dy] to x+dx y+dy] if double = 1)
% double   : optional choice parameter, defining the number of heads
%            double = 0 : single quasi arrow (default)
%            double = 1 : double arrow 
% COLOR    : optional character, defining arrow color (default:'g')
 
if nargin == 6
   color  = 'g';
   double = 0;
elseif nargin == 7
   color  = 'g';
end

[nx,ny] = size(x);
x  = reshape(x,nx*ny,1);
y  = reshape(y,nx*ny,1);
z  = reshape(z,nx*ny,1);
dx = reshape(dx,nx*ny,1);
dy = reshape(dy,nx*ny,1);
dz = reshape(dz,nx*ny,1);

if ~double
   h0 = line([x x+dx]', [y y+dy]', [z z+dz]');
else
   h0 = line([x-dx x+dx]', [y-dy y+dy]', [z-dz z+dz]');
end

set(h0,'color',color);

if nargout>0
   h = h0;
end



