function plstress(sigma,sigmadir,coord,top,mat,ivar,itime,idim)

% plstress(sigma,sigmadir,coord,top,mat,ivar,itime,idim)
%
% create a combined colour & vector plot of nodal stresses. Primarily
% intended for principal stresses (see PRINCSTR)
%
% SIGMA    : nodal stress amplitude data, may be both in multidimenisonal
%            and oridinary form
%            if multidimensional:
%            MDGETMAT(SIGMA,INODE,IVAR,ITIME) = stress type IVAR on node 
%            INODE on time ITIME. Usually IVAR=1 indicates the first principal
%            stress etc. 
%            if ordinary form:
%            SIGMA(INODE,IVAR) = stress type IVAR on node INODE 
%
% SIGMADIR : nodal stress direction data, may be in multidimensional form (filled
%            with e.g. MDPUTMAT) or oridinary matrix form.
%            if multidimensional:
%            MDGETMAT(SIGMADIR,INODE,ICOMP,IVAR,ITIME) =             
%            stress component ICOMP of stress type IVAR on node INODE
%            on time ITIME 
%            if ordinary form:
%            VECDAT(SIGMADIR,ICOMP) = stress component ICOMP on node INODE 
%             
%
% COORD    : nodal coordinates
% TOP      : mesh topology
% MAT      : material/element parameter array
% SCALE    : optional scale factor (default = 1)
% IVAR     : optional variable index (default=1)
% ITIME    : optional time step index (default=1)
% IDIM     : optional plot dimension choice parametes 
%            idim=2: 2 D plot
%            idim=3: 3 D plot
%            default IDIM = NSD (number of spatial dimensions)

error('Not updated to Matlab 5, contact Frank Baaijens');

[nnodes,nsd,nelem,maxnlnodes] = sysinfo(size(coord),size(top));

if nargin<7
   ivar = 1;
end
if nargin<8
   itime = 1;
end
if nargin<8
   idim = nsd;
end

%** get parameters, check input & set defaults
[nnodes,nsd,nelem,maxnlnodes] = sysinfo(size(coord),size(top));

%mdcheck1 = ismd(sigma,length(sigma));
%mdcheck2 = ismd(sigmadir,length(sigmadir));
%if xor(mdcheck1,mdcheck2)
%   error('input arrays must be both multidimensional or both regular')
%end
if ~mdcheck1   
   [n1,m1] = size(sigma);
   [n2,m2] = size(sigmadir);
   nvar    = m1;
   if (n1~=nnodes) | (nvar<ivar)
       error('Illegal size of array SIGMA')
   end
   if (n2~=nnodes) | (m2~=nsd*nvar)
       error('Illegal size of array SIGMADIR')
   end
 
   sigma    = sigma(:,ivar);
   sigmadir = sigmadir(:,((ivar-1)*nsd+1):(ivar*nsd));

   nsol = 1;

else

   l    = mdsize(sigma);
   nsol = l(3); 
   
end

ndir = nsd;         

%** create color plot
h = plnoddat(sigma,coord,top,mat,ivar,itime,idim);
set(h,'edgecolor','none')

%** select data for vector plot
ii = unique(nonzeros(top(:,1:maxnlnodes))); % plot all nodes used by elements
if mdcheck1
   sigmadirdat = mdgetmat(sigmadir,ii,ivar,[],itime);
else
   sigmadirdat = sigmadir(ii,:);
end

%** set up plot data
c  = 0.02*(max(max(coord))-min(min(coord)));
x  = coord(ii,1);
dx = c*sigmadirdat(:,1);
y  = coord(ii,2);
dy = c*sigmadirdat(:,2);
if nsd==3
   z  = coord(ii,3);
   dz = c*sigmadirdat(:,3);
end 

%** plot vectors
if nsd==2 
   plqarrow(x,y,dx,dy,1,'w')
else
   plqarrw3(x,y,z,dx,dy,dz,1,'w')
end



