function [h,hcrv] = plusrcrv(usrcrv,coord,colorstyle,labels,plarw);

%
% [h,hcrv] = plusrcrv(usrcrv,coord,colorstyle,labels,plarw);
%
%
% plots user curves in a 2D mesh
%
% COORD      : nodal point coordinates
% USRCRV     : nodal points indexes of nodes on user curves
% LABELS     : (optional) choice paramater, indicating if point and curve
%              labels must be plotted (1) or not (0). Default = 1 
% plarw      : 0 (default), if 1, plot the arrow
%
% plot function

if nargin<3
   colorstyle = 'c-';
end
if nargin<4
   labels = 1;
end
if nargin<5,
   plarw=0;
end


if isempty(colorstyle), colorstyle ='c-'; end

color = colorstyle(1);
style = colorstyle(2:length(colorstyle));

colors = jet;
ncolor = length(colors(:,1));

nsd = length(coord(1,:));

h0 = [];
%** user curves
if ~isempty(usrcrv),
   ncrv = length(usrcrv(:,1));
   dcolor = floor(ncolor/ncrv);
   ccolor = flipud(colors(ncolor:-dcolor:1,:));
   for icrv=1:ncrv
      crvp = nonzeros(usrcrv(icrv,:));
      if ~isempty(crvp)
         crvcoord = coord(crvp,:);   
         h1=line(crvcoord(:,1),crvcoord(:,2),'Color',ccolor(icrv,:),'Linestyle',style,'linew',2);
         h0 = [ h0 ; h1 ];
         if labels
            midnode = round(length(crvp)/2);          
            hcrv(icrv)=text(crvcoord(midnode,1),crvcoord(midnode,2),[ 'C' num2str(icrv) ]);
            ext=get(hcrv(icrv),'ext');
            pos=get(hcrv(icrv),'pos');
            dxy=crvcoord(midnode+1,:)-crvcoord(midnode,:);
            if abs(dxy(2))>abs(dxy(1)),
               set(hcrv(icrv),'pos',pos(1:2)+[ext(3) 0]);
            else
               set(hcrv(icrv),'pos',pos(1:2)+[0 ext(4)]);
            end
            if plarw,
               dxy=crvcoord(midnode+1,:)-crvcoord(midnode,:);
               plarrow(crvcoord(midnode,1),crvcoord(midnode,2),dxy(1),dxy(2));
            end
            
         end
      end
   end
end

if nargout>0
    h = h0;
 end
 
