function [] = plvec(sol,coord,top,dest,mat,scale,original,idim,nodes)

% plvec(sol,coord,top,dest,mat)
% plvec(sol,coord,top,dest,mat,scale)
% plvec(sol,coord,top,dest,mat,scale,original)
% plvec(sol,coord,top,dest,mat,scale,original,idim)
% plvec(sol,coord,top,dest,mat,scale,original,idim,nodes)
%
% plots original and original mesh
%
% input:
%   sol          : displacements, may be either in solution type form or as
%                  nodal displacements
%   coord        : nodal coordinates
%   top          : mesh topology
%   dest         : destination array 
%   mat          : optional material/element parameter array
%   scale    (1) : optional scale factor (default = 1)
%   original (1) : optional choice parameter, indicating whether the original mesh 
%                  must be drawn fully (2), boundary only (1) or not (0)
%                  if (original==-1), only deformed boundary is shown
%                  default = 1
%   idim    (nsd): optional plot dimension choice parametes 
%                  idim=2: 2 d plot
%                  idim=3: 3 d plot
%                  default idim = nsd (number of spatial dimensions)%


[nnodes,nsd] = size(coord);

%** check input / set defaults
if nargin<5
   mat=[];
end
if nargin<6
   scale=1;
end
if nargin<7
   original = 1;
end
if nargin<8
   idim = nsd;
end

[nnodes,nsd,nelem,maxnlnodes,iimat,iitype]=sysinfo(size(coord),size(top));
if nargin<9,
   nodes=1:nnodes; 
end


%** set parameters
color    = 'r';
colororg = 'y';

nldof        = length(dest(1,:));
if nsd>3  
   coord = coord(:,1:3); %* length of coord might be >nsd for plate elements
   nsd=3;
end
if idim>nsd
   coord = [coord zeros(nnodes,idim-nsd) ];
end

%** if required, extract nodal displacements from solution vector
[m,n] = size(sol);
if n==1;
   %** sol is solution type vector, extract nodal displacements
   noddisp    = sol2nod(sol,dest(1:nnodes,:));
elseif m==nnodes & n>=nsd
   %** sol is already in nodal form
   noddisp = sol;
else
   error('illegal size of array sol')
end

%** use only components 1:idim (required for e.g. plate elements)
if idim>size(noddisp,2)
   noddisp = [noddisp zeros(nnodes,idim-size(noddisp,2)) ];
else
   noddisp    = noddisp(:,1:idim);
end

%** compute displaced coordinates
coorddisp = coord + scale*noddisp;

%** plot
if idim==2

   a = top2grph(coord,top,mat);
   gplot(a-a',coord,color); axis('off'); axis('image');
else

   a = top2grph(coord,top,mat);

end

%** set up plot data   
x  = coord(nodes,1);
dx = scale*noddisp(nodes,1);
y  = coord(nodes,2);
dy = scale*noddisp(nodes,2);
if nsd==3
   z  = coord(nodes,3);
   dz = scale*vec(nodes,3);
end 

%** plot vectors
if idim==2 
   hvec0=plarrow(x,y,dx,dy,0,'r');
   %arrow([x y],[x+dx y+dy]);
else
   hvec0=plarrow3(x,y,z,dx,dy,dz,0,'r');
   %arrow([x y z],[x+dx y+dy z+dz]);
end

axis('image')


