function [weight,ipl] = gauss(nip,ned);

%  [weight,ipl] = gauss(nip,ned);
%  generates the weight factors and integration points. 
%
%  nip    : number of integtion points in one spacial direction
%  ned    : number of element dimensions
%
%  weight : weight factors in integration points
%  ipl    : location of integration points in parent element (-1:1)
%
% shape function

%** set up integration points and weight factor for 1 dimension
if nip==1

   ksi1d    = 0;
   weight1d = 2;

elseif nip==2

   ksi1d    = [ -1/sqrt(3) 1/sqrt(3) ];
   weight1d = [      1         1     ];

elseif nip==3

   ksi1d    = [ -sqrt(3/5)  0  sqrt(3/5) ];
   weight1d = [     5/9    8/9     5/9   ];

elseif nip==4,

   a =  0.861136311594053;
   b =  0.339981043584856;
   w1=  0.347854845137454;
   w2=  0.652145154862546;
   ksi1d    = [ -a  -b  b  a  ];
   weight1d = [  w1  w2 w2 w1 ];

else

   error([int2str(nip) 'nd order Gauss integration rule not implemented'])

end

%** extend to mulitiple dimensions
if ned==1

   ipl    = ksi1d';
   weight = weight1d;

elseif ned==2

   weight2d = weight1d'*weight1d;
   weight   = weight2d(:)';

   eta    = ones(nip,1)*ksi1d;
   ksi    = eta';
   ipl    = [ksi(:) eta(:)]; 

elseif ned==3

   weight2d = weight1d'*weight1d;
   weight2d = weight2d(:);
   weight3d = weight2d*weight1d;
   weight   = weight3d(:)';

   dzeta  = ones(nip,1)*ksi1d;
   eta    = dzeta';
   dzeta  = ones(nip,1)*(dzeta(:)');
   dzeta  = dzeta(:);

   eta    = ones(nip,1)*(eta(:)');
   ksi    = eta';
   eta    = eta(:);
   
   ksi    = ksi(:);
 
   ipl    = [ksi eta dzeta ]; 

end

