function [n,dn]=shquad4(intcoord);
%
% [n,dn] = shquad4(intcoord);
%
% shape function routine for 4 noded quad
%
% input:
%   intcoord :  local coordinates (ksi,eta) of integration points
%
% output:
%   n        :  shape functions at integration points
%   dn       :  derivative of shape functions with resp. to ksi and eta
%

nint    = length(intcoord(:,1));
nsd     = length(intcoord(1,:));
nlnodes = 4;
n       = zeros(nint,nlnodes);
dn      = zeros(nlnodes,nint*nsd);

for ip=1:nint

  %** get ksi and eta value
  ksi = intcoord(ip,1); eta = intcoord(ip,2);

  %** n(i,j): at integration point i value of shape function of node j
  n(ip,1) = (1-ksi)*(1-eta)/4;
  n(ip,2) = (1+ksi)*(1-eta)/4; 
  n(ip,3) = (1+ksi)*(1+eta)/4; 
  n(ip,4) = (1-ksi)*(1+eta)/4;

  %** dn(i,j): derivative of shape fuction of node i in the direction
  %            ksi and eta at all int. points
  k = nsd*ip-1;
  dn(1,k) = -(1-eta)/4; dn(1,k+1) = -(1-ksi)/4;
  dn(2,k) =  (1-eta)/4; dn(2,k+1) = -(1+ksi)/4;
  dn(3,k) =  (1+eta)/4; dn(3,k+1) =  (1+ksi)/4;
  dn(4,k) = -(1+eta)/4; dn(4,k+1) =  (1-ksi)/4;

end

