
function [n,dn]=shquad9(intcoord);
%
% [n,dn] = shquad9(intcoord);
%
% shape function routine for 9 noded quad
%
% input:
%   intcoord :  local coordinates (ksi,eta) of integration points
%
% output:
%   n        :  shape functions at integration points
%   dn       :  derivative of shape functions with resp. to ksi and eta
%

nint    = length(intcoord(:,1));
nsd     = length(intcoord(1,:));
nlnodes = 9;
n       = zeros(nint,nlnodes);
dn      = zeros(nlnodes,nint*nsd);

for ip=1:nint
%
% get intcoord (k1) and eta (k2) value
%
  k1 = intcoord(ip,1); k2 = intcoord(ip,2);
%
% n(i,j): at integration point i value of shape function of node j
%
  n(ip,9) = (1-k1)*(1+k1)*(1-k2)*(1+k2); 
  n(ip,8) = (1-k2)*(1+k2)*(1-k1)/2-n(ip,9)/2; 
  n(ip,6) = (1-k1)*(1+k1)*(1+k2)/2-n(ip,9)/2;
  n(ip,4) = (1-k2)*(1+k2)*(1+k1)/2-n(ip,9)/2;
  n(ip,2) = (1-k1)*(1+k1)*(1-k2)/2-n(ip,9)/2; 
  n(ip,7) = (1-k1)*(1+k2)/4-(n(ip,6)+n(ip,8))/2-n(ip,9)/4; 
  n(ip,5) = (1+k1)*(1+k2)/4-(n(ip,4)+n(ip,6))/2-n(ip,9)/4;
  n(ip,3) = (1+k1)*(1-k2)/4-(n(ip,2)+n(ip,4))/2-n(ip,9)/4;
  n(ip,1) = (1-k1)*(1-k2)/4-(n(ip,2)+n(ip,8))/2-n(ip,9)/4;
%
  k = 2*ip-1;
%
% dn(i,j): derivative of shape fuction of node i in the direction
%               intcoord and eta at all int. points
%
  dn(9,k)   = -(1+k1)*(1-k2)*(1+k2) + (1-k1)*(1-k2)*(1+k2);
  dn(9,k+1) = -(1-k1)*(1+k1)*(1+k2) + (1-k1)*(1+k1)*(1-k2);
  dn(8,k)   = -(1-k2)*(1+k2)/2 -                   dn(9,k  )/2;  
  dn(8,k+1) = -(1+k2)*(1-k1)/2 + (1-k2)*(1-k1)/2 - dn(9,k+1)/2;
  dn(6,k)   = -(1+k1)*(1+k2)/2 + (1-k1)*(1+k2)/2 - dn(9,k  )/2;
  dn(6,k+1) =  (1-k1)*(1+k1)/2 -                   dn(9,k+1)/2;
  dn(4,k)   =  (1-k2)*(1+k2)/2 -                   dn(9,k  )/2;
  dn(4,k+1) = -(1+k2)*(1+k1)/2 + (1-k2)*(1+k1)/2 - dn(9,k+1)/2;
  dn(2,k)   = -(1+k1)*(1-k2)/2 + (1-k1)*(1-k2)/2 - dn(9,k  )/2;
  dn(2,k+1) = -(1-k1)*(1+k1)/2 -                   dn(9,k+1)/2;
  dn(7,k)   = -(1+k2)/4-(dn(6,k  )+dn(8,k  ))/2-dn(9,k  )/4;
  dn(7,k+1) =  (1-k1)/4-(dn(6,k+1)+dn(8,k+1))/2-dn(9,k+1)/4;
  dn(5,k)   =  (1+k2)/4-(dn(4,k  )+dn(6,k  ))/2-dn(9,k  )/4;
  dn(5,k+1) =  (1+k1)/4-(dn(4,k+1)+dn(6,k+1))/2-dn(9,k+1)/4;
  dn(3,k)   =  (1-k2)/4-(dn(2,k  )+dn(4,k  ))/2-dn(9,k  )/4;
  dn(3,k+1) = -(1+k1)/4-(dn(2,k+1)+dn(4,k+1))/2-dn(9,k+1)/4;
  dn(1,k)   = -(1-k2)/4-(dn(2,k  )+dn(8,k  ))/2-dn(9,k  )/4;
  dn(1,k+1) = -(1-k1)/4-(dn(2,k+1)+dn(8,k+1))/2-dn(9,k+1)/4;
end;

