function [n,dn]=shtri3(intcoord);
%
% [n,dn]=shtri3(intcoord);
%
%
% shape function routine for 3 noded triangular element
%
% input:
%   intcoord :  local coordinates (intcoord,eta) of integration points
%
% output:
%   n        :  shape functions at integration points
%   dn       :  derivative of shape functions with resp. to intcoord and eta
%

nint    = length(intcoord(:,1));
nsd     = length(intcoord(1,:));
n       = zeros(nint,3);
dn      = zeros(3,nint*2);


if nsd~=3 & nsd~=2,
   error('This shape function only valid for 2D problems');
end


% la1=x;
% la2=y;
% la3=1-x-y;

k1 =   intcoord(:,1);
k2 =   intcoord(:,2);
k3 = 1-intcoord(:,1)-intcoord(:,2);

n(:,1) = k1;
n(:,2) = k2;
n(:,3) = k3;

k = 1:2:nint*2;

dn(1,k) =   ones(1,nint); 
dn(2,k) =  zeros(1,nint);
dn(3,k) =  -ones(1,nint);

dn(1,k+1) = zeros(1,nint); 
dn(2,k+1) =  ones(1,nint);
dn(3,k+1) = -ones(1,nint);





