function [n,dn,detj]=shtri3(intcoord,coord);
%
% [n,dn,detj]=shtri3(intcoord,coord);
%
%
% shape function routine for 3 noded triangular element
%
% input:
%   intcoord :  local coordinates (intcoord,eta) of integration points
%   coord    :  nodal coordinates
%
% output:
%   n        :  shape functions at integration points
%   dn       :  derivative of shape functions with resp. to intcoord and eta
%   detj     :  det(jacobian)
%
% remark:
%   if (nlnodes==6 | nlnodes==7), nodes [1 3 5] are used to compute shape f.
%

nint    = length(intcoord(:,1));
nsd     = length(intcoord(1,:));
nlnodes = length(coord(:,1));
n       = zeros(nint,3);
dn      = zeros(nlnodes,nint*2);


if nsd~=3,
   error('This shape function only valid for 2D problems');
end

if (nlnodes==6 | nlnodes==7),
 ii=[1 3 5];
 coord=coord(ii,:);
end

delta = (coord(3,1)-coord(2,1)) * (coord(1,2)-coord(2,2)) - ...
        (coord(2,2)-coord(3,2)) * (coord(2,1)-coord(1,1));
detj=delta/2;

dla1dx = (coord(2,2)-coord(3,2))/delta;
dla2dx = (coord(3,2)-coord(1,2))/delta;
dla3dx = (coord(1,2)-coord(2,2))/delta;

dla1dy = (coord(3,1)-coord(2,1))/delta;
dla2dy = (coord(1,1)-coord(3,1))/delta;
dla3dy = (coord(2,1)-coord(1,1))/delta;

for ip=1:nint

    k1 = intcoord(ip,1);
    k2 = intcoord(ip,2);
    k3 = intcoord(ip,3);

    n(ip,1) = k1;
    n(ip,2) = k2;
    n(ip,3) = k3 ;

    k = 2*ip-1;

    dn(1,k) = dla1dx; 
    dn(2,k) = dla2dx;
    dn(3,k) = dla3dx;

    dn(1,k+1) = dla1dy; 
    dn(2,k+1) = dla2dy;
    dn(3,k+1) = dla3dy;

end



