function [n,dn]=shtri4(intcoord);
%
% [n,dn]=shtri4(intcoord);
%
%
% shape function routine for 4 noded triangular element (4'th node is bubble)
%
% input:
%   intcoord :  local coordinates (intcoord,eta) of integration points
%
% output:
%   n        :  shape functions at integration points
%   dn       :  derivative of shape functions with resp. to intcoord and eta
%
%

nint    = length(intcoord(:,1));
nsd     = length(intcoord(1,:));
nlnodes = 4;
n       = zeros(nint,nlnodes);
dn      = zeros(nlnodes,nint*2);


if nsd~=3 & nsd~=2,
   error('This shape function only valid for 2D problems');
end

% la1=x;
% la2=y;
% la3=1-x-y;

dla1dx=1;
dla1dy=0;
dla2dx=0;
dla2dy=1;
dla3dx=-1;
dla3dy=-1;

k1 =   intcoord(:,1);
k2 =   intcoord(:,2);
k3 = 1-intcoord(:,1)-intcoord(:,2);


k1 =   intcoord(:,1);
k2 =   intcoord(:,2);
k3 = 1-intcoord(:,1)-intcoord(:,2);


n(:,1) = k1 - 9*k1.*k2.*k3;
n(:,2) = k2 - 9*k1.*k2.*k3;
n(:,3) = k3 - 9*k1.*k2.*k3;
n(:,4) = 27*k1.*k2.*k3;

k = 1:2:nint*2;

k1=k1'; k2=k2'; k3=k3';

facx=dla1dx*k2.*k3 + k1*dla2dx.*k3 + k1.*k2*dla3dx;
facy=dla1dy*k2.*k3 + k1*dla2dy.*k3 + k1.*k2*dla3dy;

dn(1,k) = dla1dx - 9*facx; 
dn(2,k) = dla2dx - 9*facx;
dn(3,k) = dla3dx - 9*facx;
dn(4,k) = 27*facx;

dn(1,k+1) = dla1dy - 9*facy; 
dn(2,k+1) = dla2dy - 9*facy;
dn(3,k+1) = dla3dy - 9*facy;
dn(4,k+1) = 27*facy;



