function [n,dn,detj]=shtri4(intcoord,coord);
%
% [n,dn,detj]=shtri4(intcoord,coord);
%
%
% shape function routine for 4 noded triangular element (4'th node is bubble)
%
% input:
%   intcoord :  local coordinates (intcoord,eta) of integration points
%   coord    :  nodal coordinates
%
% output:
%   n        :  shape functions at integration points
%   dn       :  derivative of shape functions with resp. to intcoord and eta
%   detj     :  det(jacobian)
%
%

nint    = length(intcoord(:,1));
nsd     = length(intcoord(1,:));
nlnodes = length(coord(:,1));
n       = zeros(nint,nlnodes);
dn      = zeros(nlnodes,nint*2);


if nsd~=3,
   error('This shape function only valid for 2D problems');
end


delta = (coord(3,1)-coord(2,1)) * (coord(1,2)-coord(2,2)) - ...
        (coord(2,2)-coord(3,2)) * (coord(2,1)-coord(1,1));
detj=delta/2;

dla1dx = (coord(2,2)-coord(3,2))/delta;
dla2dx = (coord(3,2)-coord(1,2))/delta;
dla3dx = (coord(1,2)-coord(2,2))/delta;

dla1dy = (coord(3,1)-coord(2,1))/delta;
dla2dy = (coord(1,1)-coord(3,1))/delta;
dla3dy = (coord(2,1)-coord(1,1))/delta;

for ip=1:nint

    k1 = intcoord(ip,1);
    k2 = intcoord(ip,2);
    k3 = intcoord(ip,3);

    n(ip,1) = k1 - 9*k1*k2*k3;
    n(ip,2) = k2 - 9*k1*k2*k3;
    n(ip,3) = k3 - 9*k1*k2*k3;
    n(ip,4) = 27*k1*k2*k3;

    k = 2*ip-1;

    facx=dla1dx*k2*k3 + k1*dla2dx*k3 + k1*k2*dla3dx;
    facy=dla1dy*k2*k3 + k1*dla2dy*k3 + k1*k2*dla3dy;

    dn(1,k) = dla1dx - 9*facx; 
    dn(2,k) = dla2dx - 9*facx;
    dn(3,k) = dla3dx - 9*facx;
    dn(4,k) = 27*facx;

    dn(1,k+1) = dla1dy - 9*facy; 
    dn(2,k+1) = dla2dy - 9*facy;
    dn(3,k+1) = dla3dy - 9*facy;
    dn(4,k+1) = 27*facy;

%    facxx=dla1dx*dla2dx*k3 + dla1dx*k2*dla3dx+...
%          dla1dx*dla2dx*k3 + k1*dla2dx*dla3dx+...
%          dla1dx*k2*dla3dx + k1*dla2dx*dla3dx;
%
%    facyy=dla1dy*dla2dy*k3 + dla1dy*k2*dla3dy+...
%          dla1dy*dla2dy*k3 + k1*dla2dy*dla3dy+...
%          dla1dy*k2*dla3dy + k1*dla2dy*dla3dy;

end


