function [n,dn,detj]=shtri6(intcoord,coord);
%
% [n,dn,detj]=shtri6(intcoord,coord);
%
%
% shape function routine for 6 noded triangular element
%
% input:
%   intcoord :  local coordinates (intcoord,eta) of integration points
%
% output:
%   n        :  shape functions at integration points
%   dn       :  derivative of shape functions with resp. to intcoord and eta
%   detj     :  det(jacobian)
%

nint    = length(intcoord(:,1));
nsd     = length(intcoord(1,:));
nlnodes = length(coord(:,1));
n       = zeros(nint,nlnodes);
dn      = zeros(nlnodes,nint*2);


if nsd~=3,
   error('This shape function only valid for 2D problems');
end


delta = (coord(5,1)-coord(3,1)) * (coord(1,2)-coord(3,2)) - ...
        (coord(3,2)-coord(5,2)) * (coord(3,1)-coord(1,1));

detj=delta/2;

dla1dx = (coord(3,2)-coord(5,2))/delta;
dla2dx = (coord(5,2)-coord(1,2))/delta;
dla3dx = (coord(1,2)-coord(3,2))/delta;

dla1dy = (coord(5,1)-coord(3,1))/delta;
dla2dy = (coord(1,1)-coord(5,1))/delta;
dla3dy = (coord(3,1)-coord(1,1))/delta;



for ip=1:nint

    k1 = intcoord(ip,1);
    k2 = intcoord(ip,2);
    k3 = intcoord(ip,3);

    n(ip,1) = k1*(2*k1-1);
    n(ip,2) = k2*(2*k2-1);
    n(ip,3) = k3*(2*k3-1);
    n(ip,4) = 4*k1*k2;
    n(ip,5) = 4*k2*k3;
    n(ip,6) = 4*k1*k3;

    k = 2*ip-1;

    dn(1,k) = dla1dx*(2*k1-1)+k1*2*dla1dx; 
    dn(2,k) = dla2dx*(2*k2-1)+k2*2*dla2dx;
    dn(3,k) = dla3dx*(2*k3-1)+k3*2*dla3dx;
    dn(4,k) = 4*dla1dx*k2+4*k1*dla2dx;
    dn(5,k) = 4*dla2dx*k3+4*k2*dla3dx;
    dn(6,k) = 4*dla1dx*k3+4*k1*dla3dx;

    dn(1,k+1)= dla1dy*(2*k1-1)+k1*2*dla1dy; 
    dn(2,k+1)= dla2dy*(2*k2-1)+k2*2*dla2dy;
    dn(3,k+1)= dla3dy*(2*k3-1)+k3*2*dla3dy;
    dn(4,k+1)= 4*dla1dy*k2+4*k1*dla2dy;
    dn(5,k+1)= 4*dla2dy*k3+4*k2*dla3dy;
    dn(6,k+1)= 4*dla1dy*k3+4*k1*dla3dy;


end


ii=[1 4 2 5 3 6];

n(:,1:6)=n(:,ii);
dn=dn(ii,:);



