function [n,dn]=shtri7(intcoord);
%
% [n,dn]=shtri7(intcoord);
%
%
% shape function routine for 7 noded triangular element
%
% input:
%   intcoord :  local coordinates (intcoord,eta) of integration points
%
% output:
%   n        :  shape functions at integration points
%   dn       :  derivative of shape functions with resp. to intcoord and eta
%


nint    = length(intcoord(:,1));
nsd     = length(intcoord(1,:));
nlnodes = 7;
n       = zeros(nint,nlnodes);
dn      = zeros(nlnodes,nint*2);


if nsd~=3 & nsd~=2,
   error('This shape function only valid for 2D problems');
end


% la1=x;
% la2=y;
% la3=1-x-y;

dla1dx= 1;
dla1dy= 0;
dla2dx= 0;
dla2dy= 1;
dla3dx=-1;
dla3dy=-1;



k1 = intcoord(:,1);
k2 = intcoord(:,2);
k3 = 1-intcoord(:,1)-intcoord(:,2);

n(:,1) = k1.*(2*k1-1)+3*k1.*k2.*k3;
n(:,2) = k2.*(2*k2-1)+3*k1.*k2.*k3;
n(:,3) = k3.*(2*k3-1)+3*k1.*k2.*k3;
n(:,4) = 4*k1.*k2-12*k1.*k2.*k3;
n(:,5) = 4*k2.*k3-12*k1.*k2.*k3;
n(:,6) = 4*k1.*k3-12*k1.*k2.*k3;
n(:,7) = 27*k1.*k2.*k3;

k = 1:2:nint*2;

k1=k1'; k2=k2'; k3=k3';

dn(1,k) = dla1dx*(2*k1-1)+k1*2*dla1dx +...
              3*dla1dx*k2.*k3 + 3*k1*dla2dx.*k3 + 3*k1.*k2*dla3dx; 
dn(2,k) = dla2dx*(2*k2-1)+k2*2*dla2dx +...
              3*dla1dx*k2.*k3 + 3*k1*dla2dx.*k3 + 3*k1.*k2*dla3dx;
dn(3,k) = dla3dx*(2*k3-1)+k3*2*dla3dx +...
              3*dla1dx*k2.*k3 + 3*k1*dla2dx.*k3 + 3*k1.*k2*dla3dx;
dn(4,k) = 4*dla1dx*k2+4*k1*dla2dx - ...
              (12*dla1dx*k2.*k3 + 12*k1*dla2dx.*k3 + 12*k1.*k2*dla3dx);
dn(5,k) = 4*dla2dx*k3+4*k2*dla3dx - ...
              (12*dla1dx*k2.*k3 + 12*k1*dla2dx.*k3 + 12*k1.*k2*dla3dx);
dn(6,k) = 4*dla1dx*k3+4*k1.*dla3dx - ...
              (12*dla1dx*k2.*k3 + 12*k1*dla2dx.*k3 + 12*k1.*k2*dla3dx);
dn(7,k) = 27*dla1dx*k2.*k3 + 27*k1*dla2dx.*k3 + 27*k1.*k2*dla3dx;


dn(1,k+1)= dla1dy*(2*k1-1)+k1*2*dla1dy+...
               3*dla1dy*k2.*k3 + 3*k1*dla2dy.*k3 + 3*k1.*k2*dla3dy; 
dn(2,k+1)= dla2dy*(2*k2-1)+k2*2*dla2dy+...
               3*dla1dy*k2.*k3 + 3*k1*dla2dy.*k3 + 3*k1.*k2*dla3dy;
dn(3,k+1)= dla3dy*(2*k3-1)+k3*2*dla3dy+...
               3*dla1dy*k2.*k3 + 3*k1*dla2dy.*k3 + 3*k1.*k2*dla3dy;
dn(4,k+1)= 4*dla1dy*k2+4*k1*dla2dy - ...
               (12*dla1dy*k2.*k3 + 12*k1*dla2dy.*k3 + 12*k1.*k2*dla3dy);
dn(5,k+1)= 4*dla2dy*k3+4*k2*dla3dy - ...
               (12*dla1dy*k2.*k3 + 12*k1*dla2dy.*k3 + 12*k1.*k2*dla3dy);
dn(6,k+1)= 4*dla1dy*k3+4*k1*dla3dy - ...
               (12*dla1dy*k2.*k3 + 12*k1*dla2dy.*k3 + 12*k1.*k2*dla3dy);
dn(7,k+1)=27*dla1dy*k2.*k3 + 27*k1*dla2dy.*k3 + 27*k1.*k2*dla3dy;



ii=[1 4 2 5 3 6 7];

n=n(:,ii);
dn=dn(ii,:);



