function [matrix] = assemble(matrix,elmatrix,pos,ielem);
%
%  ASSEMBLE assembles a system mass or stiffness matrix or the system vector.
%
%          [mat] = assemble(mat,elmat,pos,ielem) 
%
%     returns the modified system matrix or system vector,
%     to which the current element matrix or element
%     vector has been added.     
%
%     MAT   = system matrix or vector
%     ELMAT = element matrix or vector
%     POS   = array containing the global equation numbers
%     IELEM = number of the current element to be assembled
%
% system function

if isempty(elmatrix)
   return
end

% Size of the matrix
[ndof,nvec] = size(matrix);

% Determine row and column assembling positions in system matrix and vector 
ipos = pos(ielem,find(pos(ielem,:)));         

if  ndof~=nvec

   % Assemble element vector(s) in system vector(s) 
   [i,j,s] = find(elmatrix);
   matrix = matrix + sparse(ipos(i),j,s,ndof,nvec);

else

   % Assemble element matrix in system matrix 
   [i,j,s] = find(elmatrix);
   matrix = matrix + sparse(ipos(i),ipos(j),s,ndof,ndof);

end;

