% SOLUTION OF A CONVECTION-DIFFUSION PRPOBLEM WITH FEMLIN_CD
%
% du/dt + a du/dx = d/dx(c du/dx) + f
%
% Last change:  Cees Oomens 21-5-2008

%%%%%%%%%%           DEFINE THE MESH          %%%%%%%%%%

disp(' start 2-D convection diffusion ')

clear all ; 
close all ;

% Define the user points of  the domain 

points=[
   0 0; 
   1 0; 
   2 2; 
   0 1];

% curve definition [point1 point2 numberofelements dummy bias]

n  =  5 ;	% number of elements in the x-direction
m  =  5 ;	% number of elements in the y-direction
 
curves=[1 2 n 1 1
        2 3 m 1 1
        3 4 n 1 1
        4 1 m 1 1];

% Definition of subareas by means of curves curves 
 
subarea=[1 2 3 4 1];

norder=2;	% element order 1: bi-linear elements, 
            %               2: bi-quadratic elements

% create the mesh

[top,coord,usercurves]=crmesh(curves,subarea,points,norder);
plmesh(coord,top)
disp(' mesh created ')

%%%%%     CONTROLPARAMETERS FOR TIME INTEGRATION       %%%%%

istat=1;	% 1: stationary solution,
            % 2: instationary solution

if istat==2, 
   ntime = 10;    % Number of time-steps
   dt    = 0.1;   % Magnitude of the time-step
   theta = 0.5;   % Value of theta used in the theta-scheme
end

%%%%%%%%%%   DEFINE THE MATERIAL PROPERTIES      %%%%%%%%%%

mat.mat(1)=1; % c : diffusion coefficient
mat.mat(2)=0; % fx: parameter used in elcd_a to determine fluid velocity
mat.mat(3)=0; % fy: parameter used in elcd_a to determine fluid velocity
mat.mat(11)=norder+2;

mat.types='elcd';	% convection diffusion element

%%%%%%%%%% DEFINE THE BOUNDARY CONDITIONS %%%%%%%%%%

bndcon=[];
crv=1;
dof=1;
iplot=0;        %1: plots the mesh and boundary conditions;
                %0: no-plot
string='x';
bndcon=addbndc(bndcon,coord,top,mat,usercurves,crv,dof,string,iplot);

crv=3;
dof=1;
iplot=0;
string='y.^2';
bndcon=addbndc(bndcon,coord,top,mat,usercurves,crv,dof,string,iplot);

nodfrc=[];

%%%%%%%%%%%%%%      PROBLEM SOLUTION     %%%%%%%%%%%%%%%%

femlin_cd
disp(' problem solved ')

%%%%%%%%%%%%%%%      POST-PROCESSING      %%%%%%%%%%%%%%%%

figure
if istat==1,
   conoddat(sol(dest),coord,top,mat);
else
   for i=1:4
      subplot(2,2,i)
      conoddat(sol(dest,2*i),coord,top,mat);
      title(['t=' num2str(2*i*dt)]);
   end
end

