%Script to solve two-dimensional convection-diffusion problems with mlfem_nac
%
% Definition of variables:
%                   nnodes: number of nodes
%                   nsd   : space dimension (1 or 2)
%                   nelem : number of elements
%                   maxnlnodes: maximum number of nodes in an element
%                   iimat: location of material type in TOP array
%                   iitype: location of element type in TOP array
%                   q:   the global stiffness matrix 
%                   rhs: the global right-hand-side column
%                   qk:  the global stiffness matrix
%                   qm:  the global mass matrix
%                   qd:  the global damping matrix
%
%   Last change:     Cees Oomens 14-5-2008 

[nnodes,nsd,nelem,maxnlnodes,iimat,iitype]=sysinfo(size(coord),size(top));

%**** nodal forces                                                
nodfrc = [];

disp('** create equation numbers ...');

% Compute the pos and dest array
[pos,dest] = equatnr(coord,top,mat);

options     = [1 1 1 1 1]; 
% options: used in sysbuild to build systems of equations
% options(1): build mass matrix
% 		 (2): build damping matrix
% 		 (3): build stiffness matrix
% 		 (4): build rhs
% 		 (5): pass only one element topology etc to element function

nodaldata   = [];
elemdata_in = [];
elemparam   = [];

bndcon_org=bndcon;

ndof=max(max(dest));

if istat==1,     % steady state solution
   sol=zeros(ndof,1);
elseif istat==2, %unsteady solution
   sol=zeros(ndof,ntime);
   % The initial condition should be defined in sol(:,1).
   % Default the initial condition is zero for all nodes
end

disp(' -- Start of matrix-building process ...')
[qm,qd,qk,rhs] = sysbuild(coord,top,mat,pos,dest,options,[],[],[],[]);


if istat==1,
   %* solve the system of equations, steady state problem
   q=qk+qd;
   sol=solvestat(q,rhs,bndcon,[],dest);
   
elseif istat==2,
   %* unsteady solution
   q=qm/dt+theta*qd+theta*qk;
   soln=sol(:,1);
   
   for itime=1:ntime
      disp(['>>> Start of time step' num2str(itime) ]);
      rhsn=rhs+(qm/dt-(1-theta)*(qd+qk))*soln;
      sol(:,itime)=solvestat(q,rhsn,bndcon,[],dest);
      soln=sol(:,itime);
   end
   
end


