% This script analyses the bending of a bar
%
%
%       last change: Cees Oomens 14-5-2008

disp(' start demo bending of a bar ')

clear, close all

%%%%%%%%%%    DEFINE THE MESH    %%%%%%%%%%
L = 10;   % Length of the bar
H =  1;   % Height of the bar

itype =  1; % form of the element used in crmesh. 
            %      itype=1 : quadrilateral element 
            %      itype=20: regular triangular element
            
norder = 2; % order of the element. 
            %      norder=1: (bi-)linear element
            %      norder=2: (bi-)quadratic element

% Define the userpoints

points=[0 0
        L 0
        L H
        0 H];

n=10;      % number of elements in the x-direction
m=1;       % number of elements in the y-direction

% curve definition 
% format [point1 point2 numbelem dummy bias]

curves=[
   1 2 n 1 1; 
   2 3 m 1 1
   3 4 n 1 1;
   4 1 m 1 1];

%Divide the model different subareas 

subarea=[1 2 3 4 1];

% create the mesh
[top,coord,usercurves,userpoints,usersurfaces,topbnd]=crmesh(curves,subarea,points,norder,itype);

disp(' mesh created ')

%%%%%%%%%% DEFINE THE MATERIAL PROPERTIES %%%%%%%%%%
E   =   1;   %  Young's modulus
nu  = 0.3;   %  Poisson's ratio
axi =   2;   %  0 plane strain
             %  1 axi symmetric
             %  2 plane stress

mat.mat=[E nu axi];

if itype<10,
   mat.mat(11)=norder+2;
else
   mat.mat(11)=itype-20+norder;
end

mat.types='ele';  % linear elastic element

%%%%%%%%%% DEFINE THE BOUNDARY CONDITIONS %%%%%%%%%%

bndcon=[];

crv=4;      
dof=[1 2];  
string='0'; 
iplot=1;    %  1: plots the mesh and boundary conditions
            %  0: no-plot

bndcon=addbndc(bndcon,coord,top,mat,usercurves,crv,dof,string,iplot);

F=1e-4;
nodfrc=[userpoints(3) 2 -F];

%%%%%%%%%%%%%%%%%%      Solve the problem               %%%%
t0=cputime;
femlin_e;

disp('problem solved ')

%%%% postprocess the data %%%%
disp(['CPU-time consumption in femlin_e : ' num2str(cputime-t0)]);

figure(1)
pldisp(sol,coord,top,dest,mat)

figure(2)
plelmdat(sigma_elm,coord,top,mat,1);

% Calculate analytical solution

B=1;
I=B*H^3/12;
u_exact=-(F*L^3)/(3*E*I);

disp(['Computed displacement at x=L : ' num2str(sol(dest(userpoints(3),2))) ]);
disp(['Exact displacement at x=L    : ' num2str(u_exact)]);
disp(['u_L/U_c                      : ' num2str(sol(dest(userpoints(3),2))/u_exact)]);
