% Script to analyse the pure bending case
%
%
% Last change: Cees Oomens 14-5-2008

disp(' start demo pure bending ')

close all, clear

%%%%%%%%%%DEFINE THE MESH%%%%%%%%%%
L=1;% L: length of the domain
D=1;% D: height of the domain

itype=20;   % itype=1 : quadrilateral element itype=20: regular triangular element
norder=1;  % norder=1: (bi-)linear element norder=2: (bi-)quadratic element

% Define user points
points=[0 0; L 0; L D; 0 D];

n=1; % number of elements in the x-direction
m=1; % number of elements in the y-direction

% curve definition [point1 point2 numberofelements dummy bias] 
curves=[
   1 2 n 1 1; 
   2 3 m 1 1
   3 4 n 1 1;
   4 1 m 1 1];

% define subareas
subarea=[1 2 3 4 1];

% create the mesh 
[top,coord,usercurves,userpoints,usersurfaces,topbnd]=crmesh(curves,subarea,points,norder,itype);

disp(' mesh created ')

%%%%%%%%%% DEFINE THE MATERIAL PROPERTIES %%%%%%%%%%

E    =  1;   %   Young's modulus
nu   =0.3;   %   Poisson's ratio
axi  =  0;   %   0 plane strain; 1 axi-symmetric; 2 plane stress
mat.mat=[E nu axi];
if itype<10,
   mat.mat(11)=norder+2;
else
   mat.mat(11)=itype-20+norder;
end

mat.types='ele'; % linear elastic element

%%%%%%%%%% DEFINE THE BOUNDARY CONDITIONS %%%%%%%%%%
bndcon=[];

% along crv 4 the displacement in the 1 direction are set to zero
crv=4;      
dof=[1];    
string='0'; 
iplot=0;    

bndcon=addbndc(bndcon,coord,top,mat,usercurves,crv,dof,string,iplot);

% suppress the displacement in the 2 direction at userpoint 1.
bndcon=[
   bndcon
   userpoints(1) 2 0];

%nodal forces. Point loads at userpoints 2 and 3
F=1e-2;
nodfrc=[
   userpoints(3) 1 F
   userpoints(2) 1 -F
];

%%%%Solve the problem using the 1D fem program FEMLIN_E %%%%
femlin_e

disp(' problem solved ')

%%%% postprocess the data %%%%
subplot(1,2,1)
pldisp(sol,coord,top,dest,mat)

% plot the normal stress in x-direction sxx
subplot(1,2,2)
ivar=1;
plelmdat(sigma_elm,coord,top,mat,ivar);
