% Script analysis a (simple) shear test
%
%
%   last Change: Cees Oomens 14-5-2008

clear, close all

disp(' start demo shear ')

% specify either simple shear (simple_shear=1) or a shearing test (simple_shear=0).
simple_shear=0;

%%%%%%%%%%            DEFINE THE MESH            %%%%%%%%%%
L=10;% Length
H=1; % Height

itype=1;   % itype=1 : quadrilateral element itype=20: regular triangular element
norder=2;  % norder=1: (bi-)linear element norder=2: (bi-)quadratic element

% Define userpoints

points=[0 0; L 0; L H; 0 H];

n=20;  %   number of elements in the x-direction
m=10;  %   number of elements in the y-direction

% curve definition [point1 point2 numberofelements dummy bias] 

curves=[
   1 2 n 1 1; 
   2 3 m 1 1
   3 4 n 1 1;
   4 1 m 1 1];

% Define subareas 
subarea=[1 2 3 4 1];

% Create the mesh 
[top,coord,usercurves,userpoints,usersurfaces,topbnd]=crmesh(curves,subarea,points,norder,itype);

disp(' mesh created ')

%%%%%%%%%% DEFINE THE MATERIAL PROPERTIES %%%%%%%%%%
E   =   1;      %   Young's modulus
nu  = 0.3;      %   Poisson's ratio
axi =   0;      %   0 plane strain; 1 axi-symmetric; 2 plane stress
mat.mat=[E nu axi];
if itype<10,
   mat.mat(11)=norder+2;
else
   mat.mat(11)=itype-20+norder;
end

mat.types='ele';% linear elastic element

%%%%%%%%%% DEFINE THE BOUNDARY CONDITIONS %%%%%%%%%%
bndcon=[];
crv=1;      
dof=[1 2];  
string='0'; 
iplot=0;    

bndcon=addbndc(bndcon,coord,top,mat,usercurves,crv,dof,string,iplot);

crv=3;
dof=1;
string='0.2';
bndcon=addbndc(bndcon,coord,top,mat,usercurves,crv,dof,string,iplot);

dof=2;
string='0';
bndcon=addbndc(bndcon,coord,top,mat,usercurves,crv,dof,string,iplot);

% If simple shear also specify the boundary condition along the left
% and right edge.

if simple_shear
   crv=[2 4];
   dof=1;
   string='y';
   bndcon=addbndc(bndcon,coord,top,mat,usercurves,crv,dof,string,iplot);
   
   dof=2;
   string='0';
   bndcon=addbndc(bndcon,coord,top,mat,usercurves,crv,dof,string,iplot);

end

nodfrc=[];

%%%%Solve the problem using the 1D fem program FEMLIN_E %%%%
femlin_e

disp(' problem solved ')

% plot the deformed geometry
figure(1)
pldisp(sol,coord,top,dest,mat)

% plot the shear stresses
figure(2)
plelmdat(sigma_elm,coord,top,mat,3)
