
% Finite Element main programme to solve linear elastic problems.
% 
%Definition of variables:
%                   nnodes: number of nodes
%                   nsd   : space dimension (1 or 2)
%                   nelem : number of elements
%                   maxnlnodes: maximum number of nodes in an element
%                   iimat: location of material type in TOP array
%                   iitype: location of element type in TOP array
%                   q:   the global stiffness matrix 
%                   rhs: the global right-hand-side column
%                   
%   Last change:     Cees Oomens 14-5-2008 

[nnodes,nsd,nelem,maxnlnodes,iimat,iitype]=sysinfo(size(coord),size(top));


disp('** create equation numbers ...');
[pos,dest] = equatnr(coord,top,mat);

options     = [1 1 1 1 1]; 
% options: used in sysbuild to build systems of equations
% options(1): build mass matrix
% 			(2): build damping matrix
% 			(3): build stiffness matrix
% 			(4): build rhs
% 			(5): pass only one element topology etc to element function

ndof=max(max(dest));

sol=zeros(ndof,1);

disp(' -- Start of matrix-building process ...')
[qm,qc,q,rhs] = sysbuild(coord,top,mat,pos,dest,options,[],[],[],[]);

% solution
sol=solvestat(q,rhs,bndcon,nodfrc,dest);

% compute derived quantities
[sigma_elm,sigma_int,elweight] = sysdrv(coord,top,mat,pos,dest,sol,[],[],[]);

